<?php
if ( ! class_exists( 'IPTrac_Db' )) {

    /**
     * Class for manage plugin database
     */
    class IPTrac_Db
    {
        /**
         * Take db version
         *
         * @var string
         */
        public $version = '1.0';
        
        /**
         * Class construct
         *
         * @return void
         */
        public function __construct()
        {
            global $iptrac_db_version;
            $iptrac_db_version = $this->version;
        }
        
        /**
         * Database query
         *
         * @return string
         */
        public function query()
        {
            $sql  = '';
            $sql .= $this->queryTicket();
            $sql .= $this->queryAttachment();
            $sql .= $this->queryHistory();
            $sql .= $this->queryProduct();
            $sql .= $this->queryVersion();
            $sql .= $this->queryType();
            $sql .= $this->queryFocus();
            return $sql;
        }
        
        /**
         * install
         *
         * @return void
         */
        public function install()
        {
            global $wpdb, $iptrac_db_version;
            $installed_ver = get_option( "iptrac_db_version" );
            
            if( ! $installed_ver || ( $installed_ver != $iptrac_db_version ) ) {

                $sql = $this->query();

                require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
                dbDelta( $sql );

                update_option( "iptrac_db_version", $iptrac_db_version );
            }
        }
        
        /**
         * update
         *
         * @return void
         */
        public function update()
        {
            global $iptrac_db_version;
            if ( get_site_option( 'iptrac_db_version' ) != $iptrac_db_version ) {
                $this->install();
            }
        }
        
        /**
         * Table ticket
         *
         * @return string
         */
        public function queryTicket()
        {
            global $wpdb;
            
            $table_name = $wpdb->prefix . 'iptrac_ticket';
            $sql = "CREATE TABLE $table_name (
                        tick_id         int(11)             NOT NULL AUTO_INCREMENT,
                        prod_id         int(11)             NOT NULL,
                        vers_id         int(11)             NOT NULL,
                        type_id         int(11)             NOT NULL,
                        focus_id        int(11)             NOT NULL,
                        staff_id        int(11)             NOT NULL,
                        user_id         int(11)             NOT NULL,
                        tick_status     smallint  DEFAULT 0 NOT NULL,
                        tick_created    datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
                        tick_modified   datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
                        tick_token      varchar(255)        NOT NULL,
                        tick_summary    text                NOT NULL,
                        tick_desc       text                NOT NULL,
                    PRIMARY KEY  ticket_id (tick_id),
                    KEY product_id (prod_id),
                    KEY version_id (vers_id),
                    KEY type_id (type_id),
                    KEY focus_id (focus_id),
                    KEY user_id (user_id)
            );";

            return $sql;
        }
        
        /**
         * Table attachment
         *
         * @return string
         */
        public function queryAttachment()
        {
            global $wpdb;
            
            $table_name = $wpdb->prefix . 'iptrac_attachment';
            $sql = "CREATE TABLE $table_name (
                        att_id          int(11)             NOT NULL AUTO_INCREMENT,
                        tick_id         int(11)             NOT NULL,
                        post_id         int(11)             NOT NULL,
                    PRIMARY KEY  attachment_id (att_id),
                    KEY ticket_id (tick_id),
                    KEY post_id (post_id)
            );";

            return $sql;
        }
        
        /**
         * Table history
         *
         * @return string
         */
        public function queryHistory()
        {
            global $wpdb;
            
            $table_name = $wpdb->prefix . 'iptrac_history';
            $sql = "CREATE TABLE $table_name (
                        hist_id         int(11)             NOT NULL AUTO_INCREMENT,
                        tick_id         int(11)             NOT NULL,
                        user_id         int(11)             NOT NULL,
                        hist_date       datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
                        hist_user_type  smallint  DEFAULT 0 NOT NULL,
                        hist_type       smallint  DEFAULT 0 NOT NULL,
                        hist_token      varchar(255)        NOT NULL,
                        hist_message    text                NOT NULL,
                    PRIMARY KEY  history_id (hist_id),
                    KEY ticket_id (tick_id),
                    KEY user_id (user_id)
            );";

            return $sql;
        }
        
        /**
         * Table product
         *
         * @return string
         */
        public function queryProduct()
        {
            global $wpdb;
            
            $table_name = $wpdb->prefix . 'iptrac_product';
            $sql = "CREATE TABLE $table_name (
                        prod_id         int(11)             NOT NULL AUTO_INCREMENT,
                        prod_title      varchar(255)        NOT NULL,
                        prod_desc       text                NOT NULL,
                    PRIMARY KEY  product_id (prod_id)
            );";

            return $sql;
        }
        
        /**
         * Table version
         *
         * @return string
         */
        public function queryVersion()
        {
            global $wpdb;
            
            $table_name = $wpdb->prefix . 'iptrac_version';
            $sql = "CREATE TABLE $table_name (
                        vers_id         int(11)             NOT NULL AUTO_INCREMENT,
                        prod_id         int(11)             NOT NULL,
                        vers_label      varchar(255)        NOT NULL,
                    PRIMARY KEY  version_id (vers_id)
            );";

            return $sql;
        }
        
        /**
         * Table type
         *
         * @return string
         */
        public function queryType()
        {
            global $wpdb;
            
            $table_name = $wpdb->prefix . 'iptrac_type';
            $sql = "CREATE TABLE $table_name (
                        type_id         int(11)             NOT NULL AUTO_INCREMENT,
                        type_label      varchar(255)        NOT NULL,
                    PRIMARY KEY  type_id (type_id)
            );";

            return $sql;
        }
        
        /**
         * Table focus
         *
         * @return string
         */
        public function queryFocus()
        {
            global $wpdb;
            
            $table_name = $wpdb->prefix . 'iptrac_focus';
            $sql = "CREATE TABLE $table_name (
                        focus_id         int(11)             NOT NULL AUTO_INCREMENT,
                        focus_label      varchar(255)        NOT NULL,
                    PRIMARY KEY  focus_id (focus_id)
            );";

            return $sql;
        }
    }

}
?>