<?php
if ( ! class_exists( 'IPTrac_Mail' )) {

    /**
     * Class for manipulating database
     */
    class IPTrac_Mail
    {
        /**
         * Send mail
         *
         * @param string $type
         * @param int    $ticketId
         * @return array
         */
        public function send( $type, $ticketId )
        {
            $model    = new IPTrac_Model();
            $setting  = new IPTrac_Setting();
            $ticketId = absint( $ticketId );
            if ( $ticket = $model->getTicket( $ticketId )) 
            {
                $activity = self::getActivity( $type );
                $args = array( 
                    '{user}', 
                    '{date}',  
                    '{ticket}' 
                );
                $replace = array(
                    $ticket->user_nicename,
                    mysql2date( 'd F Y, h:i:s', $ticket->tick_modified ),
                    $ticket->tick_summary
                );
                $cargs = array_merge( $args, array(
                    '{activity}'
                ));
                $creplace = array_merge( $replace, array(
                    $activity
                ));
                
                add_filter( 'wp_mail_content_type', array( __CLASS__, 'setHtmlContentType' ) );
                
                if ( $setting->getSetting( 'user_notif', 1, true ) == 1 )
                {
                    if ( $user = get_userdata( $ticket->user_id ) ) 
                    {
                        $to      = $user->user_email;
                        $subject = $setting->getSetting( 'user_notif_subject', __( 'Ticket Update', 'wpiptrac' ) );
                        $subject = str_replace( $args, $replace, $subject );
                        //Content
                        $content   = $setting->getSetting( 'user_notif_format', '' );
                        $content   = str_replace( $cargs, $creplace, $content );
                        //Send mail
                        @wp_mail($to, $subject, $content );
                    }
                }
                if ( $setting->getSetting( 'staff_notif', 1, true ) == 1 )
                {
                    $to      = $ticket->user_email;
                    $subject = $setting->getSetting( 'staff_notif_subject', __( 'Ticket Update', 'wpiptrac' ) );
                    $subject = str_replace( $args, $replace, $subject );
                    //Content
                    $content   = $setting->getSetting( 'staff_notif_format', '' );
                    $content   = str_replace( $cargs, $creplace, $content );
                    //Send mail
                    @wp_mail($to, $subject, $content );
                }
                $globalSet   = $setting->getSetting( 'global_notif', 1, true );
                $globalEmail = $setting->getSetting( 'global_email' );
                if ( $globalSet == 1 && ! empty( $globalEmail ) )
                {
                    $subject = $setting->getSetting( 'staff_notif_subject', __( 'Ticket Update', 'wpiptrac' ) );
                    $subject = str_replace( $args, $replace, $subject );
                    //Content
                    $content   = $setting->getSetting( 'staff_notif_format', '' );
                    $content   = str_replace( $cargs, $creplace, $content );
                    //Send mail
                    @wp_mail($globalEmail, $subject, $content );
                }
                
                remove_filter( 'wp_mail_content_type', array( __CLASS__, 'setHtmlContentType' ) );
            }
        }
        
        /**
         * Get activity
         *
         * @param string $type
         * @return string
         */
        public function getActivity( $type )
        {
            $activity = __( 'updating ticket', 'wpiptrac' );
            if ( $type == 'send-ticket' ) {
                $activity = __( 'Send a new ticket', 'wpiptrac' );
            } elseif( $type == 'send-message' ) {
                $activity = __( 'Sending a message', 'wpiptrac' );
            } elseif( $type == 'close-ticket' ) {
                $activity = __( 'Closing ticket', 'wpiptrac' );
            } elseif( $type == 'reopen-ticket' ) {
                $activity = __( 'Reopening ticket', 'wpiptrac' );
            }
            return $activity;
        }
        
        /**
         * Set Html Content Type
         *
         * @return string
         */
        public function setHtmlContentType()
        {
            return 'text/html';
        }
    }
}