<?php
if ( ! class_exists( 'IPTrac_TableType' )) {

    /**
     * Class for display table of type data
     */
    class IPTrac_TableFocus extends WP_List_Table
    {
        /**
         * Get a list of columns. The format is:
         * 'internal-name' => 'Title'
         *
         * @return array
         */
        public function get_columns() 
        {
            $posts_columns                  = array();
            $posts_columns['label']         = __( 'Label', 'wpiptrac' );
            $posts_columns['actions']       = __( 'Actions', 'wpiptrac' );
            return $posts_columns;
        }


        /**
         * Get a list of sortable columns. The format is:
         * 'internal-name' => 'orderby'
         * or
         * 'internal-name' => array( 'orderby', true )
         *
         * The second format will make the initial sorting order be descending
         *
         * @return array
         */
        public function get_sortable_columns() 
        {
            return array(
                'label'     => __( 'Label', 'wpiptrac' )
            );
        }

        /**
         * Get a list of all, hidden and sortable columns, with filter applied
         *
         * @return array
         */
        public function get_column_info() 
        {
            $columns  = $this->get_columns();
            $hidden   = array();
            $sortable = array();
            $this->_column_headers = array( $columns, $hidden, $sortable );
            return $this->_column_headers;
        }

        /**
         * Prepares the list of items for displaying.
         * @uses WP_List_Table::set_pagination_args()
         *
         */
        public function prepare_items() 
        {
            global $wpdb, $per_page;
            
            $page = 1;
            if ( ! empty( $_GET['paged'] )) {
                $page = absint( $_GET['paged'] );
            }
            $perpage  = $this->get_items_per_page( 'edit_wpiptrac-list_per_page' );
            $perpage  = apply_filters( 'edit_posts_per_page', $perpage, 'iptrac-list' );
            $offset   = ( $page - 1 ) * $perpage;
            $model    = new IPTrac_Model();
            $products = $model->getFocuses( '', '', $perpage, $offset );
            
            $this->items = $products;
            $total_items = $model->foundRows();
            $total_pages = ceil( $total_items / $perpage );
            $this->set_pagination_args( array(
                'total_items' => $total_items,
                'total_pages' => $total_pages,
                'per_page' => $perpage
            ) );
        }

        /**
         * Get column label
         *
         * @param object $item
         * @return void
         */
        public function column_label( $item ) 
        {
            $label = $item->focus_label;
            $link  = admin_url() . 'admin.php?page=iptrac-admin-focus&action=edit&id='.$item->focus_id;
            return '<strong><a class="row-title" href="' . $link . '">' . $label . '</a></strong>';
        }
        
        /**
         * Get column actions
         *
         * @param object $item
         * @return void
         */
        public function column_actions( $item ) 
        {
            $linkEdit = admin_url() . 'admin.php?page=iptrac-admin-focus&action=edit&id='.$item->focus_id;
            $linkDel  = '#toDeleteFocus_'.$item->focus_id;
            $actions  = '<div class="ip_focusActions">
                            <a class="ip_focusEdit ipadm-btn ipadm-btn-primary ipadm-btn-small" href="' . $linkEdit . '">' . 
                                '<i class="fa fa-pencil"></i><span class="ipadm-separator"></span>' .
                                __( 'Edit', 'wpiptrac' ) . '
                            </a>
                            <a class="ip_focusDelete ipadm-btn ipadm-btn-danger ipadm-btn-small" href="' . $linkDel . '">' .
                                '<i class="fa fa-trash-o"></i><span class="ipadm-separator"></span>' . 
                                __( 'Delete', 'wpiptrac' ) . '
                            </a>
                        </div>';
            
            return $actions;
        }

        /**
         * Get column default
         *
         */
        public function column_default() 
        {
            return '';
        }
    }

}
?>