<?php
/*
Plugin Name: WP EZ Ticketing - Lite
Plugin URI:
Description: Ticketing support plugin
Version: 1.0
Author: Free PLR Products
Author URI: http://resell-rights-weekly.com
*/

/*
    LICENSE: This source file to be part of a system developed by InstaPRoduct.
    All copyrights use this file and the code in it owned by InstaPRoduct.
    It is strictly forbidden to use, copy, modify or distribute this file and
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPTRAC_TITLE', 'WP EZ Ticketing - Lite' );
define( 'IPTRAC_FILE', __FILE__ );
define( 'IPTRAC_PATH', plugin_dir_path( __FILE__ ) );

require_once( plugin_dir_path( __FILE__ ) . "includes/setting.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/db.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/model.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/admin.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/admin-ticket.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/form.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/mail.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/sender.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/history.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/ajax.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/shortcode.php" );

/**
 * Class for generate notification
 */
if ( ! class_exists( 'IPTrac' )) {

    class IPTrac
    {
        /**
         * Setup Plugin
         */
        public function setup()
        {
            $hook = strtolower( IPTRAC_TITLE );
            $hook = preg_replace( '@[^a-zA-Z0-9\-]@', '-', $hook );

            //Install Plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'installDb' ) );

            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'updateDb' ) );

            //Plugin init
            add_action( 'admin_init', array( __CLASS__, 'init' ) );

            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'addAdminMenu' ) );

            //Add style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'printAdminStyle' ), 1000 );

            add_action( 'admin_print_scripts-toplevel_page_iptrac-user-manage', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-toplevel_page_iptrac-admin-manage', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptrac-user-send', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptrac-admin-product', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptrac-admin-type', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptrac-admin-focus', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptrac-admin-setting', array( __CLASS__, 'printAdminScript' ), 1000 );

            //Front style & script
            add_action('wp_head', array( __CLASS__, 'printStyle' ) );

        }

        /**
         * Init
         *
         * @return void
         */
        public function init()
        {
            global $iptrac_sender, $wp_roles;

            /**
             * Register Roles
             */
            // Add capability for subscriber
            $role = get_role( 'subscriber' );
            $role->add_cap( 'iptrac_subscriber_manage' );

            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'iptrac_admin_manage' );

            $wp_roles->reinit();

            /**
             * AJax Handler
             */
            $ajax = new IPTrac_Ajax();
            $ajax->exec();

            /**
             * Form handler
             **/
            if ( isset( $_GET['page'] ) && $_GET['page'] == 'iptrac-user-send' )
            {
                $handler = new IPTrac_Sender();
                $handler->run();
                $iptrac_sender = $handler;
            }
        }

        /**
         * Install Db
         *
         * @return void
         */
        public function installDb()
        {
            $db = new IPTrac_Db();
            $db->install();
        }

        /**
         * Update Db
         *
         * @return void
         */
        public function updateDb()
        {
            $db = new IPTrac_Db();
            $db->update();
        }

        /**
         * Add administrator menu
         *
         * @return void
         */
        public function addAdminMenu()
        {
            //Menu for user
            add_menu_page(
                IPTRAC_TITLE,
                IPTRAC_TITLE,
                'iptrac_subscriber_manage',
                'iptrac-user-manage',
                array( __CLASS__, 'adminPage' ),
                'dashicons-editor-help'
            );
            add_submenu_page(
                'iptrac-user-manage',
                __( 'All Tickets', 'wpiptrac' ),
                __( 'All Tickets', 'wpiptrac' ),
                'iptrac_subscriber_manage',
                'iptrac-user-manage',
                array( __CLASS__, 'adminPage' )
            );
            add_submenu_page(
                'iptrac-user-manage',
                __( 'Send Ticket', 'wpiptrac' ),
                __( 'Send Ticket', 'wpiptrac' ),
                'iptrac_subscriber_manage',
                'iptrac-user-send',
                array( __CLASS__, 'adminPage' )
            );

            //Menu for admin
            add_menu_page(
                IPTRAC_TITLE,
                IPTRAC_TITLE,
                'iptrac_admin_manage',
                'iptrac-admin-manage',
                array( __CLASS__, 'adminPage' ),
                'dashicons-editor-help',
                77
            );
            add_submenu_page(
                'iptrac-admin-manage',
                __( 'All Tickets', 'wpiptrac' ),
                __( 'All Tickets', 'wpiptrac' ),
                'iptrac_admin_manage',
                'iptrac-admin-manage',
                array( __CLASS__, 'adminPage' )
            );
            add_submenu_page(
                'iptrac-admin-manage',
                __( 'Product', 'wpiptrac' ),
                __( 'Product', 'wpiptrac' ),
                'iptrac_admin_manage',
                'iptrac-admin-product',
                array( __CLASS__, 'adminPage' )
            );
            add_submenu_page(
                'iptrac-admin-manage',
                __( 'Type Option', 'wpiptrac' ),
                __( 'Type Option', 'wpiptrac' ),
                'iptrac_admin_manage',
                'iptrac-admin-type',
                array( __CLASS__, 'adminPage' )
            );
            add_submenu_page(
                'iptrac-admin-manage',
                __( 'Focus Option', 'wpiptrac' ),
                __( 'Focus Option', 'wpiptrac' ),
                'iptrac_admin_manage',
                'iptrac-admin-focus',
                array( __CLASS__, 'adminPage' )
            );
            add_submenu_page(
                'iptrac-admin-manage',
                __( 'Settings', 'wpiptrac' ),
                __( 'Settings', 'wpiptrac' ),
                'iptrac_admin_manage',
                'iptrac-admin-setting',
                array( __CLASS__, 'adminPage' )
            );
        }

        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminPage()
        {
            $display = new IPTrac_Admin();
            $display->render();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public function printAdminStyle()
        {
            wp_deregister_style('font-awesome-style');
            wp_register_style('font-awesome-style', '//netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css', false, null);
            wp_enqueue_style('font-awesome-style');

            wp_deregister_style('insta-admin-style');
            wp_register_style('insta-admin-style', plugin_dir_url( __FILE__ ) . 'css/ipadmin.css', false, null);
            wp_enqueue_style('insta-admin-style');

            wp_deregister_style('wpiptrac-admin-style');
            wp_register_style('wpiptrac-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('wpiptrac-admin-style');

        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public function printAdminScript($hook)
        {
            wp_deregister_script('insta-admin-script');
            wp_enqueue_script(
                'insta-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/ipadmin.js',
                array( 'jquery' ),
                1,
                true
            );

            wp_deregister_script('wpiptrac-admin-script');
            wp_enqueue_script(
                'wpiptrac-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print style
         *
         * @return void
         */
        public function printStyle()
        {
        ?>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/style.css" rel="stylesheet">
        <?php
        }
    }

}
//Run plugin
IPTrac::setup();
?>