<?php
if ( ! class_exists( 'IPTrac_Admin' )) {

    /**
     * Class for handling administrator page
     */
    class IPTrac_Admin
    {
        /**
         * Render administrator page
         *
         * @return void
         */
        public function render()
        {
            $handlers = array(
                'iptrac-user-manage'    => 'userTicket',
                'iptrac-user-send'      => 'userSend',
                'iptrac-admin-manage'   => 'adminTicket',
                'iptrac-admin-product'  => 'adminProduct',
                'iptrac-admin-type'     => 'adminType',
                'iptrac-admin-focus'    => 'adminFocus',
                'iptrac-admin-setting'  => 'adminSetting',
            );
            $page = '';
            if ( ! empty( $_GET['page'] )) {
                $page = trim( $_GET['page'] );
            }
            if ( ! empty( $page ) && array_key_exists( $page, $handlers )) 
            {
                $handler = $handlers[$page];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                } 
                else {
                    wp_die( __('<h1>Page not found.</h1>', 'wpiptrac') );
                }
            }
            else {
                wp_die( __('<h1>Page not found.</h1>', 'wpiptrac') );
            }
        }
        
        /**
         * Show content admin send ticket
         *
         * @return void
         */
        public function userSend()
        {
            $admin = new IPTrac_AdminTicket();
            $admin->userSend();
        }
        
        /**
         * Show content manage ticket page
         *
         * @return void
         */
        public function userTicket()
        {
            $admin = new IPTrac_AdminTicket();
            $admin->userTicket();
        }
        
        /**
         * Show content manage ticket page
         *
         * @return void
         */
        public function adminTicket()
        {
            $admin = new IPTrac_AdminTicket();
            $admin->adminTicket();
        }
        
        /**
         * Show content manage product page
         *
         * @return void
         */
        public function adminProduct()
        {
            $action = 'manage';
            if ( ! empty( $_GET['action'] )) {
                $action = trim( $_GET['action'] );
            }
            if ( $action == 'edit' ) {
                $this->productEdit();
            }
            else {
                $this->productManage();
            }
        }
        
        /**
         * Show content manage product page
         *
         * @return void
         */
        public function productManage()
        {
        ?>
            <div id="iptrac-manage-product" class="wrap ipadm-wrap iptrac-admin">
                <div class="ipadm-inner">
                    
                    <div class="ipadm-header">
                        <div class="ipadm-page-title">
                            <h1>
                                <i class="fa fa-ticket"></i>
                                <span class="ipadm-title"><?php _e( 'Product', 'wpiptrac' ); ?></span>
                            </h1>
                        </div>
                    </div>
                    
                    <?php
                    if ( isset( $_GET['add'] ) ) :
                        if ( $_GET['add'] == 1 ) :
                    ?>
                        <div id="ipadm-messages" class="ipadm-success" style="display: block;">
                            <?php _e( 'Successfully create a product.', 'wpiptrac' ); ?>
                        </div>
                    <?php 
                        else :
                    ?>
                        <div id="ipadm-messages" class="ipadm-error" style="display: block;">
                            <?php _e( 'Failed create a product.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                        endif;
                    endif;
                    ?>
                    
                    <div class="ipadm-body">
                        
                        <div class="ipadm-main">
                        
                            <div id="col-container">
                                <div id="col-right">
                                    <div class="ipadm-manage">
                                        
                                        <div class="ipadm-table">
                                            <?php
                                            require_once( plugin_dir_path( __FILE__ ) . "table-product.php" );
                                            $paginArgs = array(
                                                "per_page" => 20 
                                            );
                                            $listTable = new IPTrac_TableProduct();
                                            $listTable->prepare_items();
                                            $listTable->display();
                                            ?>
                                        </div>
                                        
                                    </div>
                                </div>
                                <div id="col-left">
                                    <div class="col-wrap">
                                        <div class="form-wrap">
                                            <h3>Add New Product</h3>

<form action="" method="post">
    <div class="ipadm-form-main iptrac-onecolumn">

        <script type="text/javascript">
        var iptrac_msg = {
            'product_title': '<?php _e( 'You must specify the title', 'wpiptrac' ); ?>'
        };
        </script>
        <?php 
        $class = 'ipadm-field-row';
        if ( $errorTitle ) {
            $class .= ' ipadm-field-error';
        }
        ?>
        <div class="<?php echo $class; ?>">
            <div class="ipadm-label">
                <label for="input-title"><?php _e( 'Title', 'wpiptrac' ); ?> <em class="ipadm-required">(<?php _e( 'required', 'wpiptrac' ); ?>)</em></label>
            </div>
            <div class="ipadm-field">
                <?php 
                if ( $errorLabel ) {
                    echo '<p class="ipadm-alert ipadm-alert-danger">' . $errorLabel . '</p>';
                }
                $value = '';
                if ( ! empty( $_POST['title'] )) {
                    $value = $_POST['title'];
                }
                ?>
                <input type="text" class="ipadm-input ipadm-input-full" id="input-title" name="title" value="<?php echo $value; ?>" />
            </div>
        </div>
        
        <div class="ipadm-field-row">
            <div class="ipadm-label">
                <label for="input-description"><?php _e( 'Description', 'wpiptrac' ); ?></label>
            </div>
            <div class="ipadm-field">
                <?php
                $value = '';
                if ( ! empty( $_POST['description'] )) {
                    $value = $_POST['description'];
                }
                ?>
                <textarea class="ipadm-input ipadm-input-full" id="input-description" name="description"><?php echo $value; ?></textarea>
            </div>
        </div>
        
        <div class="ipadm-btn-wrap">
            <input type="submit" class="ipadm-btn ipadm-btn-primary" id="iptrac-add-product" name="do_add_product" value="Add product" />
        </div>
        
    </div>
</form>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Show content editing product page
         *
         * @return void
         */
        public function productEdit()
        {
            $model = new IPTrac_Model();
            if ( empty( $_GET['id'] )) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'wpiptrac') );
            }
            $id = absint( $_GET['id'] );
            if ( ! $product = $model->getProduct( $id ) ) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'wpiptrac') );
            }
        ?>
            <div id="iptrac-manage-product" class="wrap ipadm-wrap iptrac-admin">
                <div class="ipadm-inner">
                    <div class="ipadm-header">
                        <div class="ipadm-page-title">
                            <h1>
                                <i class="fa fa-ticket"></i>
                                <span class="ipadm-title"><?php _e( 'Edit Product', 'wpiptrac' ); ?></span>
                            </h1>
                        </div>
                    </div>
                    
                    <?php
                    if ( isset( $_GET['result'] )) :
                        if ( $_GET['result'] == 1 ) :
                    ?>
                        <div id="ipadm-messages" class="ipadm-success" style="display: block;">
                            <?php _e( 'Successfully editing product.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                    else :
                    ?>
                        <div id="ipadm-messages" class="ipadm-error" style="display: block;">
                            <?php _e( 'Failed editing product.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                        endif;
                    elseif ( isset( $_GET['add'] ) && $_GET['add'] == 1 ) :
                    ?>
                        <div id="ipadm-messages" class="ipadm-success" style="display: block;">
                            <?php _e( 'Successfully create a product. You can then add versions of the product', 'wpiptrac' ); ?>
                        </div>
                    <?php
                    endif;
                    ?>
                    
                    <div class="ipadm-body">
                        
                        <div class="ipadm-main">
                            <div class="ipadm-form-wrap">
                                <form action="" method="post">
<input type="hidden" id="value-product-id" name="product_id" value="<?php echo $product->prod_id; ?>" />
<script type="text/javascript">
var iptrac_msg = {
    'product_title': '<?php _e( 'You must specify the title', 'wpiptrac' ); ?>'
};
</script>
<div class="ipadm-form-main iptrac-onecolumn">
    
    <div class="ipadm-field-row ipadm-field-inline ipadm-field-box ipadm-clear">
        <div class="ipadm-label">
            <label for="input-title"><?php _e( 'Title', 'wpiptrac' ); ?> <em class="ipadm-required">(<?php _e( 'required', 'wpiptrac' ); ?>)</em></label>
        </div>
        <div class="ipadm-field">
            <?php 
            if ( isset( $_POST['do_edit_product'] )) {
                $value = $_POST['title'];
            } else {
                $value = $product->prod_title;
            }
            ?>
            <input type="text" class="ipadm-input ipadm-input-widest" id="input-title" name="title" value="<?php echo $value; ?>" />
        </div>
    </div>
    
    <div class="ipadm-field-row ipadm-field-inline ipadm-field-box ipadm-clear">
        <div class="ipadm-label">
            <label for="input-description"><?php _e( 'Description', 'wpiptrac' ); ?></label>
        </div>
        <div class="ipadm-field">
            <?php
            if ( isset( $_POST['do_edit_product'] )) {
                $value = $_POST['description'];
            } else {
                $value = $product->prod_desc;
            }
            ?>
            <textarea class="ipadm-input ipadm-input-widest" id="input-description" name="description" rows="6"><?php echo $value; ?></textarea>
        </div>
    </div>
    
    <div id="field-product-version" class="ipadm-field-row ipadm-field-inline ipadm-field-box ipadm-clear">
        <div class="ipadm-label">
            <label for="input-version"><?php _e( 'Version', 'wpiptrac' ); ?></label>
        </div>
        <div class="ipadm-field">
            <div class="version-list">
                <?php 
                if ( $versions = $model->getVersions( $product->prod_id ) ) :
                ?>
                    <div id="iptrac-vers-list-values">
                        <ul>
                        <?php
                        foreach( $versions as $version ) :
                        ?>
                        <li id="iptrac-version-<?php echo $version->vers_id; ?>" class="iptrac-version-item">
                            <div class="iptrac-version-label">
                                <i class="fa fa-check"></i>
                                <strong>
                                    <?php echo apply_filters( 'single_post_title', stripslashes( $version->vers_label ) ); ?>
                                </strong>
                            </div>
                            <div class="iptrac-version-actions">
                                <a class="iptrac-vers-edit" href="#"><i class="fa fa-pencil"></i> <?php _e( 'Edit', 'wpiptrac' ); ?></a>
                                <a class="iptrac-vers-delete" href="#"><i class="fa fa-trash-o"></i> <?php _e( 'Delete', 'wpiptrac' ); ?></a>
                            </div>
                        </li>
                        <?php
                        endforeach;
                        ?>
                        </ul>
                    </div>
                    <div id="iptrac-vers-list-empty" style="display:none;">
                        <p><em><?php _e( 'Version of the product has not been determined.', 'wpiptrac' ); ?></em></p>
                    </div>
                
                <?php 
                else :
                ?>
                    <div id="iptrac-vers-list-values" style="display:none;">
                        <ul></ul>
                    </div>
                    <div id="iptrac-vers-list-empty">
                        <p><em><?php _e( 'Version of the product has not been determined.', 'wpiptrac' ); ?></em></p>
                    </div>
                <?php 
                endif;
                ?>
            </div>
            <div class="iptrac-add-version ipadm-btn-wrap">
                <a href="#" class="button" id="iptrac-show-add-version">Add version</a>
            </div>
        </div>
    </div>
</div>

<div class="ipadm-btn-wrap">
    <input type="submit" class="ipadm-btn ipadm-btn-primary" id="iptrac-edit-product" name="do_edit_product" value="Edit product" />
</div>

                                </form>
                            </div>
                        </div>
                    </div>
                </div>

<div id="iptrac-add-modal" class="iptrac-modal" style="display: none;">
    <div class="iptrac-modal-inner">
        <div id="iptrac-addqtn-content" class="iptrac-modal-main">
        
            <div class="iptrac-modal-close">
                <a class="iptrac-modal-close-link" href="#">x</a>
            </div>
            
            <h3 id="iptrac-vers-add-title"><?php _e( 'Add Version', 'wpiptrac' ); ?></h3>
            <h3 id="iptrac-vers-edit-title" style="display:none;"><?php _e( 'Edit Version', 'wpiptrac' ); ?></h3>
            <br/>
            <br/>
            <div class="iptrac-modal-content">
                
                <div class="ipadm-main">
                    <div class="ipadm-form-wrap">
                        <form id="iptrac-form-add-version" action="" method="post">
        
                            <input type="hidden" id="value-product-id" name="product_id" value="<?php echo $product->prod_id; ?>" />
                            <input type="hidden" id="value-version-id" name="version_id" value="0" />
                            
                            <div class="fields">
                                <div class="ipadm-field-row ipadm-field-inline ipadm-field-box ipadm-clear">
                                    <div class="ipadm-label">
                                        <label for="input-version-label"><?php _e( 'Label', 'wpiptrac' ); ?></label>
                                    </div>
                                    <div class="ipadm-field">
                                        <input type="text" class="ipadm-input" id="input-version-label" name="version_label" value="" />
                                    </div>
                                </div>
                            </div>
                            
                            <div class="ipadm-btn-wrap iptrac-form-actions">
                                <input type="submit" class="ipadm-btn ipadm-btn-primary" id="iptrac-do-add-version" name="do_add_version" value="Add version" />
                                <input type="submit" class="ipadm-btn ipadm-btn-primary" id="iptrac-do-edit-version" name="do_edit_version" value="Edit version" style="display: none;" />
                                <a href="#" class="ipadm-btn ipadm-btn-default iptrac-modal-cancel">Cancel</a>
                            </div>
            
                        </form>
                    </div>
                </div>
                
            </div>
            
        </div>
    </div>
</div>
<div id="iptrac-modal-loader-overlay" style="display:none;">
    <div id="iptrac-modal-loader"></div>
</div>

<div id="iptrac-modal-message-overlay" style="display:none;">
    <div id="iptrac-modal-message"></div>
</div>
            </div>
        <?php 
        }
        
        /**
         * Show content manage type page
         *
         * @return void
         */
        public function adminType()
        {
            $action = 'manage';
            if ( ! empty( $_GET['action'] )) {
                $action = trim( $_GET['action'] );
            }
            if ( $action == 'edit' ) {
                $this->typeEdit();
            }
            else {
                $this->typeManage();
            }
        }
        
        /**
         * Show content manage type page
         *
         * @return void
         */
        public function typeManage()
        {
        ?>
            <div id="iptrac-manage-type" class="wrap ipadm-wrap iptrac-admin">
                <div class="ipadm-inner">
                    
                    <div class="ipadm-header">
                        <div class="ipadm-page-title">
                            <h1>
                                <i class="fa fa-ticket"></i>
                                <span class="ipadm-title"><?php _e( 'Type Option', 'wpiptrac' ); ?></span>
                            </h1>
                        </div>
                    </div>
                    
                    <?php
                    if ( isset( $_GET['add'] ) ) :
                        if ( $_GET['add'] == 1 ) :
                    ?>
                        <div id="ipadm-messages" class="ipadm-success" style="display: block;">
                            <?php _e( 'Successfully create new type.', 'wpiptrac' ); ?>
                        </div>
                    <?php 
                        else :
                    ?>
                        <div id="ipadm-messages" class="ipadm-error" style="display: block;">
                            <?php _e( 'Failed create new type.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                        endif;
                    endif;
                    ?>
                    
                    <div class="ipadm-body">
                        
                        <div class="ipadm-main">
                        
                            <div id="col-container">
                                <div id="col-right">
                                    <div class="ipadm-manage">
                                        
                                        <div class="ipadm-table">
                                            <?php
                                            require_once( plugin_dir_path( __FILE__ ) . "table-type.php" );
                                            $paginArgs = array(
                                                "per_page" => 20 
                                            );
                                            $listTable = new IPTrac_TableType();
                                            $listTable->prepare_items();
                                            $listTable->display();
                                            ?>
                                        </div>
                                        
                                    </div>
                                </div>
                                <div id="col-left">
                                    <div class="col-wrap">
                                        <div class="form-wrap">
                                            <h3>Add New Type</h3>

<form action="" method="post">
    <div class="ipadm-form-main iptrac-onecolumn">
        <script type="text/javascript">
        var iptrac_msg = {
            'type_label': '<?php _e( 'You must specify the label', 'wpiptrac' ); ?>'
        };
        </script>
        <div class="ipadm-field-row">
            <div class="ipadm-label">
                <label for="input-type-label"><?php _e( 'Label', 'wpiptrac' ); ?> <em class="ipadm-required">(<?php _e( 'required', 'wpiptrac' ); ?>)</em></label>
            </div>
            <div class="ipadm-field">
                <input type="text" class="ipadm-input ipadm-input-full" id="input-type-label" name="type_label" value="" />
            </div>
        </div>
        
        <div class="ipadm-btn-wrap">
            <input type="submit" class="ipadm-btn ipadm-btn-primary" id="iptrac-add-type" name="do_add_type" value="Add type" />
        </div>
        
    </div>
</form>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Show content editing type page
         *
         * @return void
         */
        public function typeEdit()
        {
            $model = new IPTrac_Model();
            if ( empty( $_GET['id'] )) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'iptrac') );
            }
            $id = absint( $_GET['id'] );
            if ( ! $type = $model->getType( $id ) ) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'iptrac') );
            }
        ?>
            <div id="iptrac-manage-type" class="wrap ipadm-wrap iptrac-admin">
                <div class="ipadm-inner">
                    
                    <div class="ipadm-header">
                        <div class="ipadm-page-title">
                            <h1>
                                <i class="fa fa-ticket"></i>
                                <span class="ipadm-title"><?php _e( 'Edit Type', 'wpiptrac' ); ?></span>
                            </h1>
                        </div>
                    </div>
                    
                    <?php
                    if ( isset( $_GET['result'] )) :
                        if ( $_GET['result'] == 1 ) :
                    ?>
                        <div id="ipadm-messages" class="ipadm-success" style="display: block;">
                            <?php _e( 'Successfully editing type.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                    else :
                    ?>
                        <div id="ipadm-messages" class="ipadm-error" style="display: block;">
                            <?php _e( 'Failed editing type.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                        endif;
                    endif;
                    ?>
                    
                    <div class="ipadm-body">
                        
                        <div class="ipadm-main">
                            <div class="ipadm-form-wrap">
                                <form action="" method="post">

<script type="text/javascript">
var iptrac_msg = {
    'type_label': '<?php _e( 'You must specify the label', 'wpiptrac' ); ?>'
};
</script>
<div class="ipadm-form-main iptrac-onecolumn">
    <input type="hidden" id="value-type-id" name="type_id" value="<?php echo $type->type_id; ?>" />
    <div class="ipadm-field-row ipadm-field-inline ipadm-field-box ipadm-clear">
        <div class="ipadm-label">
            <label for="input-type-label"><?php _e( 'Label', 'wpiptrac' ); ?> <em class="ipadm-required">(<?php _e( 'required', 'wpiptrac' ); ?>)</em></label>
        </div>
        <div class="ipadm-field">
            <input type="text" class="ipadm-input ipadm-input-widest" id="input-type-label" name="type_label" value="<?php echo $type->type_label; ?>" />
        </div>
    </div>
</div>

<div class="ipadm-btn-wrap">
    <input type="submit" class="ipadm-btn ipadm-btn-primary" id="iptrac-edit-type" name="do_edit_type" value="Edit type" />
</div>

                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php 
        }
        
        /**
         * Show content manage focus page
         *
         * @return void
         */
        public function adminFocus()
        {
            $action = 'manage';
            if ( ! empty( $_GET['action'] )) {
                $action = trim( $_GET['action'] );
            }
            if ( $action == 'edit' ) {
                $this->focusEdit();
            }
            else {
                $this->focusManage();
            }
        }
        
        /**
         * Show content manage focus page
         *
         * @return void
         */
        public function focusManage()
        {
        ?>
            <div id="iptrac-manage-focus" class="wrap ipadm-wrap iptrac-admin">
                <div class="ipadm-inner">
                    
                    <div class="ipadm-header">
                        <div class="ipadm-page-title">
                            <h1>
                                <i class="fa fa-ticket"></i>
                                <span class="ipadm-title"><?php _e( 'Focus Option', 'wpiptrac' ); ?></span>
                            </h1>
                        </div>
                    </div>
                    
                    <?php
                    if ( isset( $_GET['add'] ) ) :
                        if ( $_GET['add'] == 1 ) :
                    ?>
                        <div id="ipadm-messages" class="ipadm-success" style="display: block;">
                            <?php _e( 'Successfully create new focus.', 'wpiptrac' ); ?>
                        </div>
                    <?php 
                        else :
                    ?>
                        <div id="ipadm-messages" class="ipadm-error" style="display: block;">
                            <?php _e( 'Failed create new focus.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                        endif;
                    endif;
                    ?>
                    
                    <div class="ipadm-body">
                        
                        <div class="ipadm-main">
                        
                            <div id="col-container">
                                <div id="col-right">
                                    <div class="ipadm-manage">
                                        
                                        <div class="ipadm-table">
                                            <?php
                                            require_once( plugin_dir_path( __FILE__ ) . "table-focus.php" );
                                            $paginArgs = array(
                                                "per_page" => 20 
                                            );
                                            $listTable = new IPTrac_TableFocus();
                                            $listTable->prepare_items();
                                            $listTable->display();
                                            ?>
                                        </div>
                                        
                                    </div>
                                </div>
                                <div id="col-left">
                                    <div class="col-wrap">
                                        <div class="form-wrap">
                                            <h3>Add New Focus</h3>

<form action="" method="post">
    <div class="ipadm-form-main iptrac-onecolumn">
        <script type="text/javascript">
        var iptrac_msg = {
            'focus_label': '<?php _e( 'You must specify the label', 'wpiptrac' ); ?>'
        };
        </script>
        
        <?php 
        $class = 'ipadm-field-row';
        if ( $errorLabel ) {
            $class .= ' ipadm-field-error';
        }
        ?>
        <div class="<?php echo $class; ?>">
            <div class="ipadm-label">
                <label for="input-focus-label"><?php _e( 'Label', 'wpiptrac' ); ?> <em class="ipadm-required">(<?php _e( 'required', 'wpiptrac' ); ?>)</em></label>
            </div>
            <div class="ipadm-field">
                <?php 
                if ( $errorLabel ) {
                    echo '<p class="ipadm-alert ipadm-alert-danger">' . $errorLabel . '</p>';
                }
                ?>
                <input type="text" class="ipadm-input ipadm-input-full" id="input-focus-label" name="focus_label" value="" />
            </div>
        </div>
        
        <div class="ipadm-btn-wrap">
            <input type="submit" class="ipadm-btn ipadm-btn-primary" id="iptrac-add-focus" name="do_add_focus" value="Add focus" />
        </div>
        
    </div>
</form>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                    </div>
                    
                </div>
            </div>
        <?php
        }
        
        /**
         * Show content editing focus page
         *
         * @return void
         */
        public function focusEdit()
        {
            $model = new IPTrac_Model();
            if ( empty( $_GET['id'] )) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'iptrac') );
            }
            $id = absint( $_GET['id'] );
            if ( ! $focus = $model->getFocus( $id ) ) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'iptrac') );
            }
        ?>
            <div id="iptrac-manage-focus" class="wrap ipadm-wrap iptrac-admin">
                <div class="ipadm-inner">
                    
                    <div class="ipadm-header">
                        <div class="ipadm-page-title">
                            <h1>
                                <i class="fa fa-ticket"></i>
                                <span class="ipadm-title"><?php _e( 'Edit Focus', 'wpiptrac' ); ?></span>
                            </h1>
                        </div>
                    </div>
                    
                    <?php
                    if ( isset( $_GET['result'] )) :
                        if ( $_GET['result'] == 1 ) :
                    ?>
                        <div id="ipadm-messages" class="ipadm-success" style="display: block;">
                            <?php _e( 'Successfully editing focus.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                    else :
                    ?>
                        <div id="ipadm-messages" class="ipadm-error" style="display: block;">
                            <?php _e( 'Failed editing focus.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                        endif;
                    endif;
                    ?>
                    
                    <div class="ipadm-body">
                        
                        <div class="ipadm-main">
                            <div class="ipadm-form-wrap">
                                <form action="" method="post">

<script type="text/javascript">
var iptrac_msg = {
    'focus_label': '<?php _e( 'You must specify the label', 'wpiptrac' ); ?>'
};
</script>
<div class="ipadm-form-main iptrac-onecolumn">
    <input type="hidden" id="value-focus-id" name="focus_id" value="<?php echo $focus->focus_id; ?>" />
    <div class="ipadm-field-row ipadm-field-inline ipadm-field-box ipadm-clear">
        <div class="ipadm-label">
            <label for="input-focus-label"><?php _e( 'Label', 'wpiptrac' ); ?> <em class="ipadm-required">(<?php _e( 'required', 'wpiptrac' ); ?>)</em></label>
        </div>
        <div class="ipadm-field">
            <input type="text" class="ipadm-input ipadm-input-widest" id="input-focus-label" name="focus_label" value="<?php echo $focus->focus_label; ?>" />
        </div>
    </div>
</div>

<div class="ipadm-btn-wrap">
    <input type="submit" class="ipadm-btn ipadm-btn-primary" id="iptrac-edit-focus" name="do_edit_focus" value="Edit focus" />
</div>

                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php 
        }
        
        /**
         * Show content setting page
         *
         * @return void
         */
        public function adminSetting()
        {
            $setting = new IPTrac_Setting();
        ?>
            <div id="iptrac-admin-setting" class="wrap ipadm-wrap iptrac-admin">
                <div class="ipadm-inner">
                    
                    <div class="ipadm-header">
                        <div class="ipadm-page-title">
                            <h1>
                                <i class="fa fa-ticket"></i>
                                <span class="ipadm-title"><?php _e( 'Settings', 'wpiptrac' ); ?></span>
                            </h1>
                        </div>
                    </div>
                    
                    <?php
                    if ( isset( $_GET['result'] )) :
                        if ( $_GET['result'] == 1 ) :
                    ?>
                        <div id="ipadm-messages" class="ipadm-success" style="display: block;">
                            <?php _e( 'Successfully save setting.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                    else :
                    ?>
                        <div id="ipadm-messages" class="ipadm-error" style="display: block;">
                            <?php _e( 'Failed save setting.', 'wpiptrac' ); ?>
                        </div>
                    <?php
                        endif;
                    endif;
                    ?>
                    
                    <div class="ipadm-body">
                        
                        <div class="ipadm-main">
                            <div class="ipadm-form-wrap">
                                <form action="" method="post">

<div class="ipadm-form-main iptrac-onecolumn">

    <div class="ipadm-fields">
    
        <h2 class="iptrac-section-title">
            <span><?php _e( 'Notification Settings', 'wpiptrac' ); ?></span>
        </h2>
    
        <div class="ipadm-field-row ipadm-field-inline ipadm-clear">
            <div class="ipadm-label">
                <label for="input-user-notif"><?php _e( 'Notification delivery settings', 'wpiptrac' ); ?></label>
            </div>
            <div class="ipadm-field">
                <p><label>
                    <?php
                    $checked = '';
                    if ( $setting->getSetting( 'user_notif', 1, true ) == 1 )
                    {
                        $checked = ' checked="checked"';
                    }
                    ?>
                    <input type="checkbox" name="user_notif" id="input-user-notif" value="1"<?php echo $checked; ?> />
                    <?php _e( 'Send notifications to the user for each interaction to the ticket.', 'wpiptrac' ); ?>
                </label></p>
                <p><label> 
                    <?php
                    $checked = '';
                    if ( $setting->getSetting( 'staff_notif', 1, true ) == 1 )
                    {
                        $checked = ' checked="checked"';
                    }
                    ?>
                    <input type="checkbox" name="staff_notif" value="1"<?php echo $checked; ?> />
                    <?php _e( 'Send notifications to the staff for each interaction to the ticket.', 'wpiptrac' ); ?>
                </label></p>
                <div class="iptrac-global-notif">
                    <?php
                    $checked = '';
                    $display = ' style="display: none;"';
                    if ( $setting->getSetting( 'global_notif', 1, true ) == 1 )
                    {
                        $checked = ' checked="checked"';
                        $display = '';
                    }
                    ?>
                    <p><label> 
                        <input type="checkbox" id="input-global-notif" name="global_notif" value="1"<?php echo $checked; ?> />
                        <?php _e( 'Send a notification to a global email address on every interaction on all ticket.', 'wpiptrac' ); ?>
                    </label></p>
                    <div id="iptrac-global-email"<?php echo $display; ?>>
                        <label for="input-global-email">Email address: </label>
                        <input type="text" id="input-global-email" class="ipadm-input" name="global_email" value="<?php echo $setting->getSetting( 'global_email', '' ); ?>" />
                    </div>
                </div>
            </div>
        </div>
    
        <div class="ipadm-field-row ipadm-field-inline ipadm-clear">
            <div class="ipadm-label">
                <label for="input-user-notif-subject"><?php _e( 'User Notification Subject', 'wpiptrac' ); ?></label>
            </div>
            <div class="ipadm-field">
                <input type="text" class="ipadm-input ipadm-input-full" id="input-user-notif-subject" name="user_notif_subject" value="<?php echo $setting->getSetting( 'user_notif_subject', __( 'Thank you for submitting a ticket', 'wpiptrac' ) ); ?>" />
            </div>
        </div>
    
        <div class="ipadm-field-row ipadm-field-inline ipadm-clear">
            <div class="ipadm-label">
                <label for="input-user-notif-format"><?php _e( 'User Notification Content', 'wpiptrac' ); ?></label>
            </div>
            <div class="ipadm-field">
                <?php
                $content = $setting->getSetting( 'user_notif_format', '<p>Your ticket is entitled {ticket} we have received on {date}.</p>
<p>We will immediately follow this ticket by checking the validity of the ticket. If we consider valid, the ticket will be received along with the solution of the problems that you find.</p>
<p>Thank You</p>' );
                wp_editor( $content, 'user_notif_format', array( 
                    'editor_height' => 200,
                    'media_buttons' => false,
                )); 
                ?>
            </div>
        </div>
    
        <div class="ipadm-field-row ipadm-field-inline ipadm-clear">
            <div class="ipadm-label">
                <label for="input-staff-notif-subject"><?php _e( 'Staff Notification Subject', 'wpiptrac' ); ?></label>
            </div>
            <div class="ipadm-field">
                <input type="text" class="ipadm-input ipadm-input-full" id="input-staff-notif-subject" name="staff_notif_subject" value="<?php echo $setting->getSetting( 'staff_notif_subject', __( 'New Ticket', 'wpiptrac' ) ); ?>" />
            </div>
        </div>
    
        <div class="ipadm-field-row ipadm-field-inline ipadm-clear">
            <div class="ipadm-label">
                <label for="input-staff-notif-format"><?php _e( 'Staff Notification Content', 'wpiptrac' ); ?></label>
            </div>
            <div class="ipadm-field">
                <?php
                $content = $setting->getSetting( 'staff_notif_format', '<p>on {date}  has entered a new ticket from {user} with the title {title}</p>
<p>Expected soon check this ticket so that any problems found by the user can be overcome</p>
<p>Thank You</p>' );
                wp_editor( $content, 'staff_notif_format', array( 
                    'editor_height' => 200,
                    'media_buttons' => false,
                )); 
                ?>
            </div>
        </div>
    
        <div class="ipadm-btn-wrap">
            <input type="submit" id="iptrac-do-save-setting" name="do_save_setting" class="ipadm-btn ipadm-btn-primary" value="Save setting" />
        </div>
        
    </div>

</div>

                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php 
        }
    }
    
}