<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPTrac_Ajax' )) {

    class IPTrac_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            
            'iptrac_edit_ticket'           => 'editTicket',
            'iptrac_close_ticket'          => 'closeTicket',
            'iptrac_reopen_ticket'         => 'reopenTicket',
            'iptrac_accept_ticket'         => 'acceptTicket',
            'iptrac_reject_ticket'         => 'rejectTicket',
            'iptrac_delete_ticket'         => 'deleteTicket',
            'iptrac_send_message'          => 'sendMessage',
            'iptrac_add_version'           => 'addVersion',
            'iptrac_edit_version'          => 'editVersion',
            'iptrac_delete_version'        => 'deleteVersion',
            'iptrac_get_version'           => 'getVersion',
            'iptrac_get_product_version'   => 'getProductVersion',
            'iptrac_add_file'              => 'addFile',
            'iptrac_edit_file'             => 'editFile',
            'iptrac_delete_file'           => 'deleteFile',
            'iptrac_get_file'              => 'getFile',
            'iptrac_add_product'           => 'addProduct',
            'iptrac_edit_product'          => 'editProduct',
            'iptrac_delete_product'        => 'deleteProduct',
            'iptrac_add_focus'             => 'addFocus',
            'iptrac_edit_focus'            => 'editFocus',
            'iptrac_deletefocus'           => 'deleteFocus',
            'iptrac_add_type'              => 'addType',
            'iptrac_edit_type'             => 'editType',
            'iptrac_deletetype'            => 'deleteType',
            'iptrac_save_setting'          => 'saveSetting',
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            global $user_ID;
            
            if ( empty( $user_ID )) {
                echo 0;
                exit();
            }
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['iptrac'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Edit ticket
         *
         * @return void
         */
        public function editTicket()
        {
            global $user_ID;
            
            if ( ! empty( $_GET['utype'] ) && $_GET['utype'] == 2 ) {
                $userId = $user_ID;
            } else {
                $userId = 0;
            }
            
            $model  = new IPTrac_Model();
            $data   = array_merge( $_POST, $_GET );
            $ticket = false;
            if ( ! empty( $data['ticket_id'] )) {
                $tickId = absint( $data['ticket_id'] );
                $ticket = $model->getTicket( $tickId );
            }
            $result = false;
            if ( $ticket ) {
                $result = IPTrac_Form::editTicket( $ticket, $userId );
            }
            if ( $result !== false ) {
                $status = 1;
                $message = __( 'Successfully to update ticket.', 'wpiptrac' );
            }
            else {
                $status  = 0;
                $message = __( 'Failed to update ticket.', 'wpiptrac' );
            }
            if ( ! empty( $_GET['utype'] ) && $_GET['utype'] == 2 ) {
                $page = 'iptrac-user-manage';
            } else {
                $page = 'iptrac-admin-manage';
            }
            $redirect = 'admin.php?page=' . $page . '&action=edit&id='.$tickId.'&update=' . $status;
            
            echo json_encode( array(
                'status'   => $status,
                'message'  => $message,
                'redirect' => $redirect
            ) );
            die();
        }
        
        /**
         * Close ticket
         *
         * @return void
         */
        public function closeTicket()
        {
            $model  = new IPTrac_Model();
            $data   = array_merge( $_POST, $_GET );
            $ticket = false;
            $tickId = 0;
            if ( ! empty( $data['ticket_id'] )) {
                $tickId = absint( $data['ticket_id'] );
                $ticket = $model->getTicket( $tickId );
            }
            $result = false;
            if ( $ticket ) {
                $toUpdate = array(
                    'tick_status' => 3
                );
                $result = $model->updateTicket( $ticket->tick_id, $toUpdate );
            }
            $utype = 1;
            if ( ! empty( $_POST['utype'] ) ) {
                $utype = absint( $_POST['utype'] );
            }
            
            if ( $result !== false ) {
            
                $status  = 1;
                $message = __( 'Successfully to closed ticket.', 'wpiptrac' );
                //Save history
                IPTrac_History::reopenTicket( $ticket, $utype );
            }
            else {
                $status  = 0;
                $message = __( 'Failed to closed ticket.', 'wpiptrac' );
            }
            if ( $utype == 2 ) {
                $page = 'iptrac-user-manage';
            } else {
                $page = 'iptrac-admin-manage';
            }
            $redirect = 'admin.php?page=' . $page . '&action=edit&id='.$tickId.'&close=' . $status;
            
            echo json_encode( array(
                'status'   => $status,
                'message'  => $message,
                'redirect' => $redirect
            ) );
            die();
        }
        
        /**
         * Reopen ticket
         *
         * @return void
         */
        public function reopenTicket()
        {
            $model  = new IPTrac_Model();
            $data   = array_merge( $_POST, $_GET );
            $ticket = false;
            $tickId = 0;
            if ( ! empty( $data['ticket_id'] )) {
                $tickId = absint( $data['ticket_id'] );
                $ticket = $model->getTicket( $tickId );
            }
            $result = false;
            if ( $ticket ) {
                $toUpdate = array(
                    'tick_status' => 2
                );
                $result = $model->updateTicket( $ticket->tick_id, $toUpdate );
            }
            $utype = 1;
            if ( ! empty( $_POST['utype'] ) ) {
                $utype = absint( $_POST['utype'] );
            }
            
            if ( $result !== false ) {
            
                $status  = 1;
                $message = __( 'Successfully to reopened ticket.', 'wpiptrac' );
                //Save history
                IPTrac_History::reopenTicket( $ticket, $utype );
            }
            else {
                $status  = 0;
                $message = __( 'Failed to reopened ticket.', 'wpiptrac' );
            }
            if ( $utype == 2 ) {
                $page = 'iptrac-user-manage';
            } else {
                $page = 'iptrac-admin-manage';
            }
            $redirect = 'admin.php?page=' . $page . '&action=edit&id='.$tickId.'&reopen=' . $status;
            
            echo json_encode( array(
                'status'   => $status,
                'message'  => $message,
                'redirect' => $redirect
            ) );
            die();
        }
        
        /**
         * Accept ticket
         *
         * @return void
         */
        public function acceptTicket()
        {
            if ( ! current_user_can( 'iptrac_admin_manage' ) ) {
                echo 0;
                exit();
            }
            $model  = new IPTrac_Model();
            $data   = array_merge( $_POST, $_GET );
            $ticket = false;
            $tickId = 0;
            if ( ! empty( $data['ticket_id'] )) {
                $tickId = absint( $data['ticket_id'] );
                $ticket = $model->getTicket( $tickId );
            }
            $result = false;
            if ( $ticket ) {
                $toUpdate = array(
                    'tick_status' => 2
                );
                $result = $model->updateTicket( $ticket->tick_id, $toUpdate );
            }
            if ( $result !== false ) {
            
                //Save history
                IPTrac_History::acceptTicket( $ticket );
                
                $status  = 1;
                $message = __( 'Successfully to accepting ticket.', 'wpiptrac' );
            }
            else {
                $status  = 0;
                $message = __( 'Failed to accepting ticket.', 'wpiptrac' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $message,
                'redirect'  => 'admin.php?page=iptrac-admin-manage&action=edit&id='.$tickId.'&accept=' . $status
            ) );
            die();
        }
        
        /**
         * Reject ticket
         *
         * @return void
         */
        public function rejectTicket()
        {
            if ( ! current_user_can( 'iptrac_admin_manage' ) ) {
                echo 0;
                exit();
            }
            $model  = new IPTrac_Model();
            $data   = array_merge( $_POST, $_GET );
            $ticket = false;
            $tickId = 0;
            if ( ! empty( $data['ticket_id'] )) {
                $tickId = absint( $data['ticket_id'] );
                $ticket = $model->getTicket( $tickId );
            }
            $result = false;
            if ( $ticket ) {
                $toUpdate = array(
                    'tick_status' => 4
                );
                $result = $model->updateTicket( $ticket->tick_id, $toUpdate );
            }
            if ( $result !== false ) {
            
                //Save history
                IPTrac_History::rejectTicket( $ticket, 2 );
                
                $status  = 1;
                $message = __( 'Successfully to rejecting ticket.', 'wpiptrac' );
            }
            else {
                $status  = 0;
                $message = __( 'Failed to rejecting ticket.', 'wpiptrac' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $message,
                'redirect'  => 'admin.php?page=iptrac-admin-manage&action=edit&id='.$tickId.'&reject=' . $status
            ) );
            die();
        }
        
        /**
         * Processing ajax for delete ticket
         *
         * @return void
         */
        public function deleteTicket()
        {
            $model = new IPTrac_Model();
            $item  = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = $model->getTicket( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wpiptrac' )
                ) );
                die();
            }
            
            $result = $model->deleteTicket( $item->tick_id );
            if ( $result ) {
                echo json_encode( array(
                    'status'  => 1,
                    'message' => __( 'Successfully remove the ticket', 'wpiptrac' )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the ticket', 'wpiptrac' )
                ) );
            }
            die();
        }
        
        /**
         * Send message
         *
         * @return void
         */
        public function sendMessage()
        {
            $id     = 0;
            $result = false;
            $model  = new IPTrac_Model();
            if ( ! empty( $_POST['ticket_id'] )) {
                $id = absint( $_POST['ticket_id'] );
                if ( $ticket = $model->getTicket( $id ) ) 
                {
                    $result = IPTrac_Form::sendMessage();
                }
            }
            if ( $result ) {
                $status  = 1;
                $message = __( 'Successfully to send a message.', 'wpiptrac' );
            }
            else {
                $status  = 0;
                $message = __( 'Failed to send message.', 'wpiptrac' );
            }
            if ( ! empty( $_GET['utype'] ) && $_GET['utype'] == 2 ) {
                $page = 'iptrac-user-manage';
            } else {
                $page = 'iptrac-admin-manage';
            }
            $redirect = 'admin.php?page=' . $page . '&action=edit&id='.$id.'&send=' . $status;
            echo json_encode( array(
                'status'   => $status,
                'message'  => $message,
                'redirect' => $redirect
            ) );
            die();
        }
        
        /**
         * Add product
         *
         * @return void
         */
        public function addProduct()
        {
            $result = IPTrac_Form::addProduct();
            if ( $result ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to add product.', 'wpiptrac' ),
                    'id'        => $result,
                    'label'     => apply_filters( 'single_post_title', $_POST['title'] ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to add product.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Edit product
         *
         * @return void
         */
        public function editProduct()
        {
            $model   = new IPTrac_Model();
            $data    = array_merge( $_POST, $_GET );
            $product = false;
            if ( ! empty( $data['product_id'] )) {
                $prodId  = absint( $data['product_id'] );
                $product = $model->getProduct( $prodId );
            }
            $result = false;
            if ( $product ) {
                $result = IPTrac_Form::editProduct( $product );
            }
            if ( $result !== false ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to update product.', 'wpiptrac' ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to update product.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Processing ajax for delete product
         *
         * @return void
         */
        public function deleteProduct()
        {
            $model = new IPTrac_Model();
            $item  = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = $model->getProduct( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wpiptrac' )
                ) );
                die();
            }
            
            $result = $model->deleteProduct( $item->prod_id );
            if ( $result ) {
                echo json_encode( array(
                    'status'  => 1,
                    'message' => __( 'Successfully remove the product', 'wpiptrac' )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the product', 'wpiptrac' )
                ) );
            }
            die();
        }
        
        /**
         * Add focus
         *
         * @return void
         */
        public function addFocus()
        {
            $result = IPTrac_Form::addFocus();
            if ( $result ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to add focus.', 'wpiptrac' ),
                    'id'        => $result,
                    'label'     => apply_filters( 'single_post_title', $_POST['focus_label'] ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to add focus.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Edit focus
         *
         * @return void
         */
        public function editFocus()
        {
            $model  = new IPTrac_Model();
            $data   = array_merge( $_POST, $_GET );
            $focus  = false;
            if ( ! empty( $data['focus_id'] )) {
                $focusId = absint( $data['focus_id'] );
                $focus   = $model->getFocus( $focusId );
            }
            $result = false;
            if ( $focus ) {
                $result = IPTrac_Form::editFocus( $focus );
            }
            if ( $result !== false ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to update focus.', 'wpiptrac' ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to update focus.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Processing ajax for delete focus
         *
         * @return void
         */
        public function deleteFocus()
        {
            $model = new IPTrac_Model();
            $item  = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = $model->getFocus( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wpiptrac' )
                ) );
                die();
            }
            
            $result = $model->deleteFocus( $item->focus_id );
            if ( $result ) {
                echo json_encode( array(
                    'status'  => 1,
                    'message' => __( 'Successfully remove the focus', 'wpiptrac' )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the focus', 'wpiptrac' )
                ) );
            }
            die();
        }
        
        /**
         * Add type
         *
         * @return void
         */
        public function addType()
        {
            $result = IPTrac_Form::addType();
            if ( $result ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to add type.', 'wpiptrac' ),
                    'id'        => $result,
                    'label'     => apply_filters( 'single_post_title', $_POST['type_label'] ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to add type.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Edit type
         *
         * @return void
         */
        public function editType()
        {
            $model = new IPTrac_Model();
            $data  = array_merge( $_POST, $_GET );
            $type  = false;
            if ( ! empty( $data['type_id'] )) {
                $typeId = absint( $data['type_id'] );
                $type   = $model->getType( $typeId );
            }
            $result = false;
            if ( $type ) {
                $result = IPTrac_Form::editType( $type );
            }
            if ( $result !== false ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to update type.', 'wpiptrac' ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to update type.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Processing ajax for delete type
         *
         * @return void
         */
        public function deleteType()
        {
            $model = new IPTrac_Model();
            $item  = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = $model->getType( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wpiptrac' )
                ) );
                die();
            }
            
            $result = $model->deleteType( $item->type_id );
            if ( $result ) {
                echo json_encode( array(
                    'status'  => 1,
                    'message' => __( 'Successfully remove the type', 'wpiptrac' )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the type', 'wpiptrac' )
                ) );
            }
            die();
        }
        
        /**
         * Add version
         *
         * @return void
         */
        public function addVersion()
        {
            $result = IPTrac_Form::addVersion();
            if ( $result ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to add version.', 'wpiptrac' ),
                    'id'        => $result,
                    'label'     => apply_filters( 'single_post_title', $_POST['version_label'] ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to add version.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Edit version
         *
         * @return void
         */
        public function editVersion()
        {
            $model   = new IPTrac_Model();
            $data    = array_merge( $_POST, $_GET );
            $version = false;
            if ( ! empty( $data['version_id'] )) {
                $versId  = absint( $data['version_id'] );
                $version = $model->getVersion( $versId );
            }
            $result = false;
            if ( $version ) {
                $result = IPTrac_Form::editVersion( $version );
            }
            if ( $result !== false ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to update version.', 'wpiptrac' ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to update version.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Delete version
         *
         * @return void
         */
        public function deleteVersion()
        {
            $model   = new IPTrac_Model();
            $data    = array_merge( $_POST, $_GET );
            $success = false;
            
            $versId = 0;
            if ( ! empty( $data['id'] )) {
                $versId = absint( $data['id'] );
            }
            if ( $version = $model->getVersion( $versId )) {
                $result = $model->deleteVersion( $versId );
                if ( $result ) {
                    $success = true;
                }
            }
            if ( $success ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to delete version.', 'wpiptrac' ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to delete version.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Get version
         *
         * @return void
         */
        public function getVersion()
        {
            $model    = new IPTrac_Model();
            $version = false;
            if ( ! empty( $_GET['id'] )) {
                $id       = absint( $_GET['id'] );
                $version = $model->getVersion( $id );
            }
            if ( $version ) {
                $jsondata = array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to get version.', 'wpiptrac' ),
                    'id'        => $version->vers_id,
                    'label'     => stripslashes( $version->vers_label ),
                );
                echo json_encode( $jsondata );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to get version.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Get product version
         *
         * @return void
         */
        public function getProductVersion()
        {
            $model   = new IPTrac_Model();
            $product = false;
            if ( ! empty( $_GET['product'] )) {
                $id      = absint( $_GET['product'] );
                $product = $model->getProduct( $id );
            }
            $options = '';
            if ( $product ) 
            {
                if ( $versions = $model->getVersions( $id ) )
                {
                    foreach( $versions as $version ) 
                    {
                        $options .= '<option value="' . $version->vers_id . '">' . $version->vers_label . '</option>';
                    }
                }
            }
            echo $options;
        }
        
        /**
         * Add file
         *
         * @return void
         */
        public function addFile()
        {
            global $user_ID;
            
            $result = false;
            $attach = false;
            if ( ! empty( $_FILES['async-upload'] )) {
                
                $data = array();
                if ( ! empty( $_POST['file_title'] )) {
                    $data['post_title'] = apply_filters( 'single_post_title', $_POST['file_title'] );
                }
                if ( ! empty( $_POST['file_desc'] )) {
                    $data['post_content'] = mysql_real_escape_string( $_POST['file_desc'] );;
                }
                $attachId = media_handle_upload( 'async-upload', 0, $data );
                if ( is_wp_error( $attachId ) ) 
                {
                    echo json_encode( array(
                        'status'   => 0,
                        'message'  => $attachment_id->get_error_message()
                    ) );
                    die();
                }
                if ( ! $attach = wp_prepare_attachment_for_js( $attachId ) ) 
                {
                    echo json_encode( array(
                        'status'   => 0,
                        'message'  => __( 'Error adding file.', 'wpiptracp' )
                    ) );
                    die();
                }
                //Add ticket attachment data
                $model = new IPTrac_Model();
                if ( empty( $_POST['ticket_id'] )) {
                    //Add new ticket
                    $toInsert = array(
                        'user_id'       => $user_ID,
                        'tick_created'  => date('c'),
                        'tick_modified' => date('c'),
                        'tick_status'   => 3
                    );
                    $tickId = $model->insertTicket( $toInsert );
                }
                else {
                    $tickId = absint( $_POST['ticket_id'] );
                }
                if ( ! $tickId ) 
                {
                    echo json_encode( array(
                        'status'  => 0,
                        'message' => __( 'Error adding file.', 'wpiptracp' )
                    ) );
                    die();
                }
                $toInsert = array(
                    'post_id' => $attach['id'],
                    'tick_id' => $tickId
                );
                $result = $model->insertAttachment( $toInsert );
            }
            if ( $result ) 
            {
                //Add history
                IPTrac_History::addFile( $tickId, $attach['filename'], 2 );
                
                $name = '';
                if ( ! empty( $attach['title'] )) {
                    $name = $attach['title'];
                }
                elseif ( ! empty( $attach['filename'] )) {
                    $name = $attach['filename'];
                }
                echo json_encode( array(
                    'status'  => 1,
                    'message' => __( 'Successfully adding a file.', 'wpiptracp' ),
                    'id'      => $result,
                    'ticket'  => $tickId,
                    'attach'  => $attach['id'],
                    'icon'    => $attach['icon'],
                    'url'     => $attach['url'],
                    'name'    => $name
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Error adding file.', 'wpiptracp' )
                ) );
                die();
            }
        }
        
        /**
         * Edit file
         *
         * @return void
         */
        public function editFile()
        {
            $model = new IPTrac_Model();
            $data  = array_merge( $_POST, $_GET );
            $file  = false;
            if ( ! empty( $data['file_id'] )) {
                $fileId = absint( $data['file_id'] );
                $file   = $model->getAttachment( $fileId );
            }
            $result = false;
            if ( $file ) {
                $result = IPTrac_Form::editAttachment( $file );
            }
            if ( $result !== false ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to update file info.', 'wpiptrac' ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to update file info.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Processing ajax for delete file
         *
         * @return void
         */
        public function deleteFile()
        {
            $model = new IPTrac_Model();
            $file  = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $file = $model->getAttachment( $id );
            }
            if ( ! $file ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wpiptrac' )
                ) );
                die();
            }
            
            $result = $model->deleteAttachment( $file );
            if ( $result ) {
                
                //Add history
                IPTrac_History::deleteFile( $file, 2 );
                
                echo json_encode( array(
                    'status'  => 1,
                    'message' => __( 'Successfully remove the file', 'wpiptrac' )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the file', 'wpiptrac' )
                ) );
            }
            die();
        }
        
        /**
         * Get file
         *
         * @return void
         */
        public function getFile()
        {
            $model = new IPTrac_Model();
            $file  = false;
            if ( ! empty( $_GET['id'] )) {
                $id   = absint( $_GET['id'] );
                $file = $model->getAttachment( $id );
            }
            if ( $file ) {
                $jsondata = array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to get file.', 'wpiptrac' ),
                    'id'        => $file->att_id,
                    'ticket'    => $file->tick_id,
                    'title'     => stripslashes( $file->post_title ),
                    'desc'      => stripslashes( $file->post_content ),
                    'file'      => $file->guid
                );
                echo json_encode( $jsondata );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to get file.', 'wpiptrac' )
                ) );
                die();
            }
        }
        
        /**
         * Save setting
         *
         * @return void
         */
        public function saveSetting()
        {
            $model  = new IPTrac_Model();
            $data   = array_merge( $_POST, $_GET );
            $result = IPTrac_Form::saveSetting();
            if ( $result !== false ) {
                echo json_encode( array(
                    'status'    => 1,
                    'message'   => __( 'Successfully to save setting.', 'wpiptrac' ),
                ) );
                die();
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to save setting.', 'wpiptrac' )
                ) );
                die();
            }
        }
    }
    
}
?>