<?php
if ( ! class_exists( 'IPTrac_Form' )) {

    /**
     * Class for processing form
     */
    class IPTrac_Form
    {
        /**
         * Edit ticket data
         *
         * @param  object $ticket
         * @return int|false
         */
        public function editTicket( $ticket )
        {
            $result = 0;
            $data   = array();
            if ( ! empty( $_POST['summary'] ) && $_POST['summary'] != $ticket->tick_summary ) 
            {
                $data['tick_summary'] = apply_filters( 'single_post_title', $_POST['summary'] );
            }
            if ( ! empty( $_POST['description'] ) && $_POST['description'] != $ticket->tick_desc ) 
            {
                $data['tick_desc'] = mysql_real_escape_string( $_POST['description'] );
            }
            if ( ! empty( $_POST['product'] ) && $_POST['product'] != $ticket->prod_id ) 
            {
                $data['prod_id'] = absint( $_POST['product'] );
            }
            if ( ! empty( $_POST['version'] ) && $_POST['version'] != $ticket->vers_id ) 
            {
                $data['vers_id'] = absint( $_POST['version'] );
            }
            if ( ! empty( $_POST['type'] ) && $_POST['type'] != $ticket->type_id ) 
            {
                $data['type_id'] = absint( $_POST['type'] );
            }
            if ( ! empty( $_POST['focus'] ) && $_POST['focus'] != $ticket->focus_id ) 
            {
                $data['focus_id'] = absint( $_POST['focus'] );
            }
            if ( ! empty( $_POST['staff'] ) && $_POST['staff'] != $ticket->staff_id ) 
            {
                $data['staff_id'] = absint( $_POST['staff'] );
            }
            if ( ! empty( $data )) 
            {
                $model = new IPTrac_Model();
                $result = $model->updateTicket( $ticket->tick_id, $data );
            }
            return $result;
        }
        
        /**
         * Send message
         *
         * @return int|false
         */
        public function sendMessage()
        {
            global $user_ID;
            
            $result = false;
            if ( ! empty( $_POST['message'] ) && ! empty( $_POST['ticket_id'] )) 
            {
                $type = 1;
                if ( ! empty( $_POST['user_type'] )) {
                    $type = absint( $_POST['user_type'] );
                }
                $tickId = absint( $_POST['ticket_id'] );
                $result = IPTrac_History::sendMessage( $tickId, $type );
            }
            return $result;
        }
        
        /**
         * Add product data
         *
         * @return int|false
         */
        public function addProduct()
        {
            $result = false;
            if ( ! empty( $_POST['title'] )) 
            {
                $model    = new IPTrac_Model();
                $toInsert = array(
                    'prod_title' => apply_filters( 'single_post_title', $_POST['title'] ),
                    'prod_desc'  => mysql_real_escape_string( $_POST['description'] )
                );
                $result = $model->insertProduct( $toInsert );
            }
            return $result;
        }
        
        /**
         * Edit product data
         *
         * @param  object $product
         * @return int|false
         */
        public function editProduct( $product )
        {
            $result = 0;
            $data   = array();
            if ( ! empty( $_POST['title'] ) && $_POST['title'] != $product->prod_title ) 
            {
                $data['prod_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $_POST['description'] ) && $_POST['description'] != $product->prod_desc ) 
            {
                $data['prod_desc'] = mysql_real_escape_string( $_POST['description'] );
            }
            if ( ! empty( $data )) 
            {
                $model = new IPTrac_Model();
                $result = $model->updateProduct( $product->prod_id, $data );
            }
            return $result;
        }
        
        /**
         * Edit attachment data
         *
         * @param  object $file
         * @return int|false
         */
        public function editAttachment( $file )
        {
            $result = 0;
            $data   = array();
            if ( ! empty( $_POST['file_title'] ) && $_POST['file_title'] != $file->post_title ) 
            {
                $data['post_title'] = apply_filters( 'single_post_title', $_POST['file_title'] );
            }
            if ( ! empty( $_POST['file_desc'] ) && $_POST['file_desc'] != $file_->post_content ) 
            {
                $data['post_content'] = mysql_real_escape_string( $_POST['file_desc'] );
            }
            if ( ! empty( $data )) 
            {
                $data['ID']            = $file->post_id;
                $data['post_modified'] = date('c');
                $result = wp_update_post( $data );
            }
            return $result;
        }
        
        /**
         * Add version data
         *
         * @return int|false
         */
        public function addVersion()
        {
            $result = false;
            if ( ! empty( $_POST['product_id'] ) && ! empty( $_POST['version_label'] )) 
            {
                // Add version
                $toInsert = array(
                    'prod_id'       => absint( $_POST['product_id'] ),
                    'vers_label'    => apply_filters( 'single_post_title', $_POST['version_label'] )
                );
                $model  = new IPTrac_Model();
                $result = $model->insertVersion( $toInsert );
            }
            return $result;
        }
        
        /**
         * Edit version data
         *
         * @return int|false
         */
        public function editVersion( $version )
        {
            $result = 0;
            $data   = array();
            if ( ! empty( $_POST['version_label'] ) && $_POST['version_label'] != $version->vers_label ) 
            {
                $data['vers_label'] = apply_filters( 'single_post_title', $_POST['version_label'] );
            }
            if ( ! empty( $data )) 
            {
                $model  = new IPTrac_Model();
                $result = $model->updateVersion( $version->vers_id, $data );
            }
            return $result;
        }
        
        /**
         * Add type data
         *
         * @return int|false
         */
        public function addType()
        {
            $result = false;
            if ( ! empty( $_POST['type_label'] )) 
            {
                $model    = new IPTrac_Model();
                $toInsert = array(
                    'type_label' => apply_filters( 'single_post_title', $_POST['type_label'] )
                );
                $result = $model->insertType( $toInsert );
            }
            return $result;
        }
        
        /**
         * Edit type data
         *
         * @param  object $type
         * @return int|false
         */
        public function editType( $type )
        {
            $result = 0;
            if ( ! empty( $_POST['type_label'] ) && $_POST['type_label'] != $type->type_label ) 
            {
                $model = new IPTrac_Model();
                $data  = array(
                    'type_label' => apply_filters( 'single_post_title', $_POST['type_label'] )
                );
                $result = $model->updateType( $type->type_id, $data );
            }
            return $result;
        }
        /**
         * Add focus data
         *
         * @return int|false
         */
        public function addFocus()
        {
            $result = false;
            if ( ! empty( $_POST['focus_label'] )) 
            {
                $model    = new IPTrac_Model();
                $toInsert = array(
                    'focus_label' => apply_filters( 'single_post_title', $_POST['focus_label'] )
                );
                $result = $model->insertFocus( $toInsert );
            }
            return $result;
        }
        
        /**
         * Edit focus data
         *
         * @param  object $focus
         * @return int|false
         */
        public function editFocus( $focus )
        {
            $result = 0;
            if ( ! empty( $_POST['focus_label'] ) && $_POST['focus_label'] != $focus->focus_label ) 
            {
                $model = new IPTrac_Model();
                $data  = array(
                    'focus_label' => apply_filters( 'single_post_title', $_POST['focus_label'] )
                );
                $result = $model->updateFocus( $focus->focus_id, $data );
            }
            return $result;
        }
        
        /**
         * Save setting
         *
         * @return int|false
         */
        public function saveSetting()
        {
            $setting = new IPTrac_Setting();
            $data    = array();
            $struct  = $setting->getStruct();
            foreach( $struct as $name )
            {
                $value = false;
                if ( isset( $_POST[$name] )) {
                    $value = $_POST[$name];
                }
                $data[$name] = $value;
            }
            return $setting->setSettings( $data );
        }
    }
}

