<?php
if ( ! class_exists( 'IPTrac_Model' )) {

    /**
     * Class for manipulating database
     */
    class IPTrac_Model
    {
        /**
         * Get all tickets
         *
         * @param string $where
         * @param string $order
         * @param int    $limit
         * @param int    $offset
         * @return array
         */
        public function getTickets( $where = '', $order = '', $limit = 0, $offset = 0 )
        {
            global $wpdb;
            
            $table = $wpdb->prefix . 'iptrac_ticket';
            $sql   = "
                SELECT SQL_CALC_FOUND_ROWS * FROM $table WHERE 1=1
            ";
            if ( ! empty( $where )) {
                $sql .= " AND $where";
            }
            if ( ! empty( $order )) {
                $sql .= " $order";
            }
            if ( $limit != 0 ) {
                $sql .= " LIMIT $limit OFFSET $offset";
            }
            $results = $wpdb->get_results( $sql );
            return $results;
        }
        
        /**
         * Get ticket
         *
         * @param int $id
         * @param int $userId
         * @return array
         */
        public function getTicket( $id, $userId = 0 )
        {
            global $wpdb;
            
            $id     = absint( $id );
            $table  = $wpdb->prefix . 'iptrac_ticket';
            $tprod  = $wpdb->prefix . 'iptrac_product';
            $tvers  = $wpdb->prefix . 'iptrac_version';
            $ttype  = $wpdb->prefix . 'iptrac_type';
            $tfocus = $wpdb->prefix . 'iptrac_focus';
            $tuser  = $wpdb->users;
            $sql    = "
                SELECT * 
                FROM $table 
                    JOIN $tprod ON $tprod.prod_id = $table.prod_id
                    JOIN $tvers ON $tvers.vers_id = $table.vers_id
                    JOIN $ttype ON $ttype.type_id = $table.type_id
                    JOIN $tfocus ON $tfocus.focus_id = $table.focus_id
                    JOIN $tuser  ON $tuser.ID = $table.staff_id
                WHERE $table.tick_id = %d
            ";
            if ( ! empty( $userId )) {
                $sql  .= " AND $table.user_id = %d";
                $query = $wpdb->prepare( $sql, array( $id, $userId ) );
            } else {
                $query = $wpdb->prepare( $sql, $id );
            }
            $result = $wpdb->get_row( $query );
            return $result;
        }
        
        /**
         * Get all histories
         *
         * @param int    $ticketId
         * @param string $where
         * @param string $order
         * @param int    $limit
         * @param int    $offset
         * @return array
         */
        public function getHistories( $ticketId, $where = '', $order = '', $limit = 0, $offset = 0 )
        {
            global $wpdb;
            
            $tickId = absint( $ticketId );
            $table  = $wpdb->prefix . 'iptrac_history';
            $tuser  = $wpdb->users;
            $sql    = "
                SELECT SQL_CALC_FOUND_ROWS * 
                FROM $table 
                    JOIN $tuser ON $tuser.ID = $table.user_id
                WHERE 1=1 AND tick_id = $tickId
            ";
            if ( ! empty( $where )) {
                $sql .= " AND $where";
            }
            if ( ! empty( $order )) {
                $sql .= " $order";
            } else {
                $sql .= " ORDER BY $table.hist_date DESC";
            }
            if ( $limit != 0 ) {
                $sql .= " LIMIT $limit OFFSET $offset";
            }
            $results = $wpdb->get_results( $sql );
            return $results;
        }
        
        /**
         * Get history
         *
         * @param int $id
         * @return array
         */
        public function getHistory( $id )
        {
            global $wpdb;
            
            $id    = absint( $id );
            $table = $wpdb->prefix . 'iptrac_history';
            $tuser = $wpdb->users;
            $sql   = "
                SELECT * 
                FROM $table JOIN $tuser ON $tuser.ID = $table.user_id
                WHERE hist_id = %d
            ";
            $query  = $wpdb->prepare( $sql, $id );
            $result = $wpdb->get_row( $query );
            return $result;
        }
        
        /**
         * Get all attachment
         *
         * @param int    $ticketId
         * @param string $where
         * @param string $order
         * @param int    $limit
         * @param int    $offset
         * @return array
         */
        public function getAttachments( $ticketId, $where = '', $order = '', $limit = 0, $offset = 0 )
        {
            global $wpdb;
            
            $tickId = absint( $ticketId );
            $table  = $wpdb->prefix . 'iptrac_attachment';
            $tposts = $wpdb->posts;
            $sql    = "
                SELECT SQL_CALC_FOUND_ROWS * 
                    FROM $table 
                    JOIN $tposts ON $tposts.ID = $table.post_id
                WHERE 1=1 AND tick_id = $tickId
            ";
            if ( ! empty( $where )) {
                $sql .= " AND $where";
            }
            if ( ! empty( $order )) {
                $sql .= " $order";
            }
            if ( $limit != 0 ) {
                $sql .= " LIMIT $limit OFFSET $offset";
            }
            $results = $wpdb->get_results( $sql );
            return $results;
        }
        
        /**
         * Get attachment
         *
         * @param int $id
         * @return array
         */
        public function getAttachment( $id )
        {
            global $wpdb;
            
            $id     = absint( $id );
            $table  = $wpdb->prefix . 'iptrac_attachment';
            $tposts = $wpdb->posts;
            $sql    = "
                SELECT * 
                    FROM $table 
                    JOIN $tposts ON $tposts.ID = $table.post_id
                WHERE att_id = %d
            ";
            $query  = $wpdb->prepare( $sql, $id );
            $result = $wpdb->get_row( $query );
            return $result;
        }
        
        /**
         * Get all products
         *
         * @param string $where
         * @param string $order
         * @param int    $limit
         * @param int    $offset
         * @return array
         */
        public function getProducts( $where = '', $order = '', $limit = 0, $offset = 0 )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_product';
            $sql    = "
                SELECT SQL_CALC_FOUND_ROWS * FROM $table WHERE 1=1
            ";
            if ( ! empty( $where )) {
                $sql .= " AND $where";
            }
            if ( ! empty( $order )) {
                $sql .= " $order";
            }
            if ( $limit != 0 ) {
                $sql .= " LIMIT $limit OFFSET $offset";
            }
            $results = $wpdb->get_results( $sql );
            return $results;
        }
        
        /**
         * Get product
         *
         * @param int $id
         * @return array
         */
        public function getProduct( $id )
        {
            global $wpdb;
            
            $id    = absint( $id );
            $table = $wpdb->prefix . 'iptrac_product';
            $sql   = "
                SELECT * FROM $table WHERE prod_id = %d
            ";
            $query  = $wpdb->prepare( $sql, $id );
            $result = $wpdb->get_row( $query );
            return $result;
        }
        
        /**
         * Get all versions
         *
         * @param int    $prodId
         * @param string $where
         * @param string $order
         * @param int    $limit
         * @param int    $offset
         * @return array
         */
        public function getVersions( $prodId, $where = '', $order = '', $limit = 0, $offset = 0 )
        {
            global $wpdb;
            
            $prodId = absint( $prodId );
            $table  = $wpdb->prefix . 'iptrac_version';
            $sql    = "
                SELECT SQL_CALC_FOUND_ROWS * FROM $table WHERE 1=1 AND prod_id = $prodId
            ";
            if ( ! empty( $where )) {
                $sql .= " AND $where";
            }
            if ( ! empty( $order )) {
                $sql .= " $order";
            }
            if ( $limit != 0 ) {
                $sql .= " LIMIT $limit OFFSET $offset";
            }
            $results = $wpdb->get_results( $sql );
            return $results;
        }
        
        /**
         * Get version
         *
         * @param int $id
         * @return array
         */
        public function getVersion( $id )
        {
            global $wpdb;
            
            $id    = absint( $id );
            $table = $wpdb->prefix . 'iptrac_version';
            $sql   = "
                SELECT * FROM $table WHERE vers_id = %d
            ";
            $query  = $wpdb->prepare( $sql, $id );
            $result = $wpdb->get_row( $query );
            return $result;
        }
        
        /**
         * Get all types
         *
         * @param string $where
         * @param string $order
         * @param int    $limit
         * @param int    $offset
         * @return array
         */
        public function getTypes( $where = '', $order = '', $limit = 0, $offset = 0 )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_type';
            $sql    = "
                SELECT SQL_CALC_FOUND_ROWS * FROM $table WHERE 1=1
            ";
            if ( ! empty( $where )) {
                $sql .= " AND $where";
            }
            if ( ! empty( $order )) {
                $sql .= " $order";
            }
            if ( $limit != 0 ) {
                $sql .= " LIMIT $limit OFFSET $offset";
            }
            $results = $wpdb->get_results( $sql );
            return $results;
        }
        
        /**
         * Get type
         *
         * @param int $id
         * @return array
         */
        public function getType( $id )
        {
            global $wpdb;
            
            $id    = absint( $id );
            $table = $wpdb->prefix . 'iptrac_type';
            $sql   = "
                SELECT * FROM $table WHERE type_id = %d
            ";
            $query  = $wpdb->prepare( $sql, $id );
            $result = $wpdb->get_row( $query );
            return $result;
        }
        
        /**
         * Get all focuses
         *
         * @param string $where
         * @param string $order
         * @param int    $limit
         * @param int    $offset
         * @return array
         */
        public function getFocuses( $where = '', $order = '', $limit = 0, $offset = 0 )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_focus';
            $sql    = "
                SELECT SQL_CALC_FOUND_ROWS * FROM $table WHERE 1=1
            ";
            if ( ! empty( $where )) {
                $sql .= " AND $where";
            }
            if ( ! empty( $order )) {
                $sql .= " $order";
            }
            if ( $limit != 0 ) {
                $sql .= " LIMIT $limit OFFSET $offset";
            }
            $results = $wpdb->get_results( $sql );
            return $results;
        }
        
        /**
         * Get focus
         *
         * @param int $id
         * @return array
         */
        public function getFocus( $id )
        {
            global $wpdb;
            
            $id    = absint( $id );
            $table = $wpdb->prefix . 'iptrac_focus';
            $sql   = "
                SELECT * FROM $table WHERE focus_id = %d
            ";
            $query  = $wpdb->prepare( $sql, $id );
            $result = $wpdb->get_row( $query );
            return $result;
        }
        
        /**
         * Found rows
         *
         * @return int
         */
        public function foundRows()
        {
            global $wpdb;
            $sql    = "SELECT FOUND_ROWS";
            $result = $wpdb->get_var( $sql );
            return $result;
        }
        
        /**
         * Insert ticket
         *
         * @param  array $data
         * @param  array $format
         * @return void
         */
        public function insertTicket( $data, $format = array() )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_ticket';
            $data   = (array)$data;
            $result = $wpdb->insert( $table, $data, $format );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update ticket
         *
         * @param  int   $id
         * @param  array $data
         * @return void
         */
        public function updateTicket( $id, $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_ticket';
            $data   = (array)$data;
            $where  = array(
                'tick_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Delete ticket
         *
         * @param  int   $id
         * @return void
         */
        public function deleteTicket( $id )
        {
            global $wpdb;
            
            //Delete Attachment
            if ( $files = $this->getAttachments( $id ) ) 
            {
                foreach( $files as $file ) {
                    $this->deleteAttachment( $file );
                }
            }
            
            //Delete History
            $this->deleteHistories( $id );
            
            //Delete ticket
            $table  = $wpdb->prefix . 'iptrac_ticket';
            $where  = array(
                'tick_id' => absint( $id )
            );
            $result = $wpdb->delete( $table, $where );
            return $result;
        }
        
        /**
         * Insert history
         *
         * @param  array $data
         * @param  array $format
         * @return void
         */
        public function insertHistory( $data, $format = array() )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_history';
            $data   = (array)$data;
            $result = $wpdb->insert( $table, $data, $format );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update history
         *
         * @param  int   $id
         * @param  array $data
         * @return void
         */
        public function updateHistory( $id, $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_history';
            $data   = (array)$data;
            $where  = array(
                'hist_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Delete history
         *
         * @param  int   $id
         * @return void
         */
        public function deleteHistory( $id )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_history';
            $where  = array(
                'hist_id' => absint( $id )
            );
            $result = $wpdb->delete( $table, $where );
            return $result;
        }
        
        /**
         * Delete histories
         *
         * @param  int   $tickId
         * @return void
         */
        public function deleteHistories( $tickId )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_history';
            $where  = array(
                'tick_id' => absint( $tickId )
            );
            $result = $wpdb->delete( $table, $where );
            return $result;
        }
        
        /**
         * Insert attachment
         *
         * @param  array $data
         * @param  array $format
         * @return void
         */
        public function insertAttachment( $data, $format = array() )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_attachment';
            $data   = (array)$data;
            $result = $wpdb->insert( $table, $data, $format );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update attachment
         *
         * @param  int   $id
         * @param  array $data
         * @return void
         */
        public function updateAttachment( $id, $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_attachment';
            $data   = (array)$data;
            $where  = array(
                'att_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Delete attachment
         *
         * @param  object $file
         * @return void
         */
        public function deleteAttachment( $file )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_attachment';
            $where  = array(
                'att_id' => absint( $file->att_id )
            );
            $result = $wpdb->delete( $table, $where );
            if ( $result ) {
                $result = wp_delete_post( $file->post_id, true );
            }
            return $result;
        }
        
        /**
         * Insert product
         *
         * @param  array $data
         * @param  array $format
         * @return void
         */
        public function insertProduct( $data, $format = array() )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_product';
            $data   = (array)$data;
            $result = $wpdb->insert( $table, $data, $format );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update product
         *
         * @param  int   $id
         * @param  array $data
         * @return void
         */
        public function updateProduct( $id, $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_product';
            $data   = (array)$data;
            $where  = array(
                'prod_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Delete product
         *
         * @param  int   $id
         * @return void
         */
        public function deleteProduct( $id )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_product';
            $where  = array(
                'prod_id' => absint( $id )
            );
            $result = $wpdb->delete( $table, $where );
            return $result;
        }
        
        /**
         * Insert version
         *
         * @param  array $data
         * @param  array $format
         * @return void
         */
        public function insertVersion( $data, $format = array() )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_version';
            $data   = (array)$data;
            $result = $wpdb->insert( $table, $data, $format );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update version
         *
         * @param  int   $id
         * @param  array $data
         * @return void
         */
        public function updateVersion( $id, $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_version';
            $data   = (array)$data;
            $where  = array(
                'vers_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Delete version
         *
         * @param  int   $id
         * @return void
         */
        public function deleteVersion( $id )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_version';
            $where  = array(
                'vers_id' => absint( $id )
            );
            $result = $wpdb->delete( $table, $where );
            return $result;
        }
        
        /**
         * Insert type
         *
         * @param  array $data
         * @param  array $format
         * @return void
         */
        public function insertType( $data, $format = array() )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_type';
            $data   = (array)$data;
            $result = $wpdb->insert( $table, $data, $format );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update type
         *
         * @param  int   $id
         * @param  array $data
         * @return void
         */
        public function updateType( $id, $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_type';
            $data   = (array)$data;
            $where  = array(
                'type_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Delete type
         *
         * @param  int   $id
         * @return void
         */
        public function deleteType( $id )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_type';
            $where  = array(
                'type_id' => absint( $id )
            );
            $result = $wpdb->delete( $table, $where );
            return $result;
        }
        
        /**
         * Insert focus
         *
         * @param  array $data
         * @param  array $format
         * @return void
         */
        public function insertFocus( $data, $format = array() )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_focus';
            $data   = (array)$data;
            $result = $wpdb->insert( $table, $data, $format );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update focus
         *
         * @param  int   $id
         * @param  array $data
         * @return void
         */
        public function updateFocus( $id, $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_focus';
            $data   = (array)$data;
            $where  = array(
                'focus_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Delete focus
         *
         * @param  int   $id
         * @return void
         */
        public function deleteFocus( $id )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'iptrac_focus';
            $where  = array(
                'focus_id' => absint( $id )
            );
            $result = $wpdb->delete( $table, $where );
            return $result;
        }
    }
}

