<?php
if ( ! class_exists( 'IPTrac_Sender' )) {

    /**
     * Class for processing form send ticket
     */
    class IPTrac_Sender
    {
        /**
         * Take form data
         *
         * @var array
         */
        protected $_data = array();
        
        /**
         * Take form elements
         *
         * @var array
         */
        protected $_elements = array(
            'summary',
            'description',
            'product',
            'version',
            'type',
            'focus',
            'staff',
        );
        
        /**
         * Take form errors
         *
         * @var array
         */
        protected $_errors = array();
        
        /**
         * Is form submitted
         *
         * @var boolean
         */
        protected $_isSubmitted = false;
        
        /**
         * Class contructor
         *
         * @return void
         */
        public function __construct()
        {
            if ( isset( $_POST['do_send_ticket'] )) {
                $this->_isSubmitted = true;
            }
        }
        
        /**
         * Run sender
         *
         * @return void
         */
        public function run()
        {
            if ( $this->isSubmitted() ) {
                return $this->processForm();
            }
            return true;
        }
        
        /**
         * Process form
         *
         * @return void
         */
        public function processForm()
        {
            foreach( $this->_elements as $element )
            {
                $cheker = '_check' . ucfirst( $element );
                if ( method_exists( $this, $cheker ) ) {
                    $isValid = $this->$cheker();
                } 
                else {
                    $isValid = $this->_defaultChecker( $element );
                }
                if ( $isValid ) {
                    $this->_getFormValue( $element );
                }
            }
            if ( ! $this->isErrors() ) {
                $this->_processData();
            }
        }
        
        /**
         * Get form value
         *
         * @param  string $element
         * @return array
         */
        protected function _getFormValue( $element )
        {
            if ( ! empty( $_POST[$element] )) 
            {
                if ( $element == 'summary' )
                {
                    $value = apply_filters( 'single_post_title', $_POST[$element] );
                }
                elseif ( $element == 'description' ) {
                    $value = $_POST[$element];
                }
                else {
                    $value = absint( $_POST[$element] );
                }
                $this->_data[$element] = $value;
            }
        }
        
        /**
         * Process data
         *
         * @return array
         */
        protected function _processData()
        {
            global $user_ID;
            
            $model = new IPTrac_Model();
            if ( $this->isSubmitted() && ! $this->isErrors() && ! empty( $this->_data )) 
            {
                $this->isProcess = true;
                $secrret  = '@wp_iptrac_ticket_$#123@';
                $toInsert = array(
                    'user_id'           => $user_ID,
                    'prod_id'           => $this->_data['product'],
                    'vers_id'           => $this->_data['version'],
                    'type_id'           => $this->_data['type'],
                    'focus_id'          => $this->_data['focus'],
                    'staff_id'          => $this->_data['staff'],
                    'tick_summary'      => $this->_data['summary'],
                    'tick_desc'         => $this->_data['description'],
                    'tick_status'       => 1,
                    'tick_created'      => date( 'c' ),
                    'tick_modified'     => date( 'c' ),
                    'tick_token'        => md5( time() . $secret ),
                );
                //Do insert ticket
                $result = $model->insertTicket( $toInsert );
                if ( $result ) 
                {
                    IPTrac_History::sendTicket( $result, $this->_data['summary'] );
                    IPTrac_Mail::send( 'send-ticket', $result );
                    wp_redirect( 'admin.php?page=iptrac-user-send&action=addfile&ticket=' . $result );
                }
                else 
                {
                    wp_redirect( 'admin.php?page=iptrac-user-send&process=1&result=0' );
                }
            }
        }
        
        /**
         * Get elements form
         *
         * @return array
         */
        public function getElements()
        {
            return $this->_elements;
        }
        
        /**
         * Is form submitted
         *
         * @return boolean
         */
        public function isSubmitted()
        {
            return $this->_isSubmitted;
        }
        
        /**
         * Get form errors
         *
         * @return array
         */
        public function getErrors()
        {
            return $this->_errors;
        }
        
        /**
         * Get form error
         *
         * @param  string $element
         * @return false|string
         */
        public function getError( $element )
        {
            $error = false;
            if ( $this->isSubmitted() ) 
            {
                if ( array_key_exists( $element, $this->_errors )) {
                    $error = $this->_errors[$element];
                }
            }
            return $error;
        }
        
        /**
         * Get value
         *
         * @param  string $element
         * @return mixed
         */
        public function getValue( $element )
        {
            $value = '';
            if ( $this->isSubmitted() ) 
            {
                if ( ! empty( $this->_data[$element] )) {
                    $value = stripslashes( $this->_data[$element] );
                }
                elseif( ! empty( $_POST[$element] )) {
                    $value = $_POST[$element];
                }
            }
            return $value;
        }
        
        /**
         * Is any form errors?
         *
         * @return boolean
         */
        public function isErrors()
        {
            if ( empty( $this->_errors )) {
                return false;
            }
            return true;
        }
        
        /**
         * Get form data
         *
         * @return array
         */
        public function getData()
        {
            return $this->_data;
        }
        
        /**
         * Default checker
         *
         * @param  string $default
         * @return boolean
         */
        protected function _defaultChecker( $element )
        {
            $messages = array(
                'summary'       => __( 'You must specify the summary', 'wpiptrac' ),
                'description'   => __( 'You must specify the description', 'wpiptrac' ),
                'product'       => __( 'You must specify which product you find a problem', 'wpiptrac' ),
                'version'       => __( 'You must specify version of product', 'wpiptrac' ),
                'type'          => __( 'You must specify the type of problems that you find', 'wpiptrac' ),
                'focus'         => __( 'You must specify the focus of problems that you find', 'wpiptrac' ),
                'staff'         => __( 'You must specify that you expect staff to provide solutions to the problems you find', 'wpiptrac' ),
            );
            if ( empty( $_POST[$element] )) 
            {
                if ( array_key_exists( $element, $messages )) {
                    $msg = $messages[$element];
                } else {
                    $msg = __( 'You must specify data', 'wpiptrac' );
                }
                $this->_errors[$element] = $msg;
                
                return false;
            }
            return true;
        }
    }
}

