<?php
if ( ! class_exists( 'IPTrac_Setting' )) {

    /**
     * Class for manage setting
     */
    class IPTrac_Setting
    {
        /**
         * Take structure setting
         *
         * @var array
         */
        protected $_struct = array(
            'user_notif',
            'staff_notif',
            'global_notif',
            'global_email',
            'user_notif_format',
            'staff_notif_format',
            'user_notif_subject',
            'staff_notif_subject',
        );
        
        /**
         * Take data setting
         *
         * @var array
         */
        protected $_settings;
        
        /**
         * Class construct
         *
         * @return void
         */
        public function __construct()
        {
            $this->_prepare();
        }
        
        /**
         * Get struct setting
         *
         * @return array
         */
        public function getStruct()
        {
            return $this->_struct;
        }
        
        /**
         * Get all post setting
         *
         * @return string
         */
        public function getSettings()
        {
            return $this->_settings;
        }
        
        /**
         * Get post setting
         *
         * @param  string $key
         * @param  mixed  $default
         * @return string
         */
        public function getSetting( $key, $default = false, $allowEmpty = false )
        {
            $setting = $default;
            if ( $allowEmpty ) {
                if ( isset( $this->_settings[$key] ) ) {
                    $setting = $this->_settings[$key];
                }
            } else {
                if ( ! empty( $this->_settings[$key] ) ) {
                    $setting = $this->_settings[$key];
                }
            }
            return $setting;
        }
        
        /**
         * Get all post setting
         *
         * @param  array $data
         * @return boolean
         */
        public function setSettings( $data )
        {
            $data     = (array)$data;
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
            return $this->_update( $settings );
        }
        
        /**
         * Get post setting
         *
         * @param  string $key
         * @param  string $value
         * @return boolean
         */
        public function setSetting( $key, $value )
        {
            $data = array(
                $key => $value
            );
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
            return $this->_update( $settings );
        }
        
        /**
         * Reset post setting
         *
         * @return boolean
         */
        public function reset()
        {
            $data = array( 'reset' => 1 );
            return $this->_update( $data );
        }
        
        /**
         * Prepare class
         *
         * @return void
         */
        protected function _prepare()
        {
            $options = array();
            foreach( $this->_struct as $struct ) 
            {
                $key = '_iptrac_' . $struct;
                $val = get_option( $key );
                $options[$struct] = $val;
            }
            $this->_settings = $options;
        }
        
        /**
         * Update settings
         *
         * @param  array $settings
         * @return boolean
         */
        protected function _update( $settings )
        {
            $settings = (array)$settings;
            foreach( $settings as $key => $value ) 
            {
                $key = '_iptrac_' . $key;
                update_option( $key, $value );
            }
            return true;
        }
    }

}
?>