<?php
if ( ! class_exists( 'IPTrac_TableAdminTicket' )) {

    /**
     * Class for display table of product data
     */
    class IPTrac_TableAdminTicket extends WP_List_Table
    {
        /**
         * Get a list of columns. The format is:
         * 'internal-name' => 'Title'
         *
         * @return array
         */
        public function get_columns() 
        {
            $posts_columns                  = array();
            $posts_columns['summary']       = __( 'Summary', 'wpiptrac' );
            $posts_columns['created']       = __( 'Created', 'wpiptrac' );
            $posts_columns['modified']      = __( 'Modified', 'wpiptrac' );
            $posts_columns['status']        = __( 'Status', 'wpiptrac' );
            $posts_columns['actions']       = __( 'Actions', 'wpiptrac' );
            return $posts_columns;
        }


        /**
         * Get a list of sortable columns. The format is:
         * 'internal-name' => 'orderby'
         * or
         * 'internal-name' => array( 'orderby', true )
         *
         * The second format will make the initial sorting order be descending
         *
         * @return array
         */
        public function get_sortable_columns() 
        {
            return array(
                'summary'     => __( 'Summary', 'wpiptrac' )
            );
        }

        /**
         * Get a list of all, hidden and sortable columns, with filter applied
         *
         * @return array
         */
        public function get_column_info() 
        {
            $columns  = $this->get_columns();
            $hidden   = array();
            $sortable = array();
            $this->_column_headers = array( $columns, $hidden, $sortable );
            return $this->_column_headers;
        }

        /**
         * Prepares the list of items for displaying.
         * @uses WP_List_Table::set_pagination_args()
         *
         */
        public function prepare_items() 
        {
            global $wpdb, $per_page;
            
            $page = 1;
            if ( ! empty( $_GET['paged'] )) {
                $page = absint( $_GET['paged'] );
            }
            $perpage  = $this->get_items_per_page( 'edit_wpiptrac-list_per_page' );
            $perpage  = apply_filters( 'edit_posts_per_page', $perpage, 'iptrac-list' );
            $offset   = ( $page - 1 ) * $perpage;
            $model    = new IPTrac_Model();
            
            $where = '';
            if ( ! empty( $_GET['user'] )) 
            {
                $users  = (array)$_GET['user'];
                $where .= ' AND user_id IN (' . implode( ',', $users ) . ')';
            }
            if ( ! empty( $_GET['product'] )) 
            {
                $prods  = (array)$_GET['product'];
                $where .= ' AND prod_id IN (' . implode( ',', $prods ) . ')';
            }
            if ( ! empty( $_GET['type'] )) 
            {
                $types  = (array)$_GET['type'];
                $where .= ' AND type_id IN (' . implode( ',', $types ) . ')';
            }
            if ( ! empty( $_GET['focus'] )) 
            {
                $focuses  = (array)$_GET['focus'];
                $where   .= ' AND focus_id IN (' . implode( ',', $focuses ) . ')';
            }
            if ( ! empty( $_GET['status'] )) 
            {
                $statuses = (array)$_GET['status'];
                $where   .= ' AND tick_status IN (' . implode( ',', $statuses ) . ')';
            }
            if ( ! empty( $_GET['date_start'] ) && ! empty( $_GET['date_end'] )) 
            {
                $hrsOffset = get_option('gmt_offset');
                if (strpos($hrsOffset, '-') !== 0) $hrsOffset = '+' . $hrsOffset;
                $hrsOffset .= ' hours';
                
                $dateRangeEnd   = strtotime($_GET['date_end']);
                $dateRangeStart = strtotime($_GET['date_start']);

                $dateStart = date('c', $dateRangeStart);
                $dateEnd   = date('c', $dateRangeEnd); 
                
                $where .= ' AND tick_created BETWEEN "' . $dateStart . '" AND "' . $dateEnd . '"';
            }
            $tickets  = $model->getTickets( $where, '', $perpage, $offset );
            
            $this->items = $tickets;
            $total_items = $model->foundRows();
            $total_pages = ceil( $total_items / $perpage );
            $this->set_pagination_args( array(
                'total_items' => $total_items,
                'total_pages' => $total_pages,
                'per_page' => $perpage
            ) );
        }

        /**
         * Get column summary
         *
         * @param object $item
         * @return void
         */
        public function column_summary( $item ) 
        {
            $title = $item->tick_summary;
            $link  = admin_url() . 'admin.php?page=iptrac-admin-manage&action=edit&id='.$item->tick_id;
            return '<strong><a class="row-title" href="' . $link . '">' . $title . '</a></strong>';
        }

        /**
         * Get column created
         *
         * @param object $item
         * @return void
         */
        public function column_created( $item ) 
        {
            return mysql2date( 'd M Y, h:i', $item->tick_created );
        }

        /**
         * Get column modified
         *
         * @param object $item
         * @return void
         */
        public function column_modified( $item ) 
        {
            return mysql2date( 'd M Y, h:i', $item->tick_modified );
        }

        /**
         * Get column status
         *
         * @param object $item
         * @return void
         */
        public function column_status( $item ) 
        {
            $label  = __( 'Invalid', 'wpiptrac' );
            $status = $item->tick_status;
            if ( $status == 1 ) {
                $label = __( 'Awaiting Review', 'wpiptrac' );
            } elseif ( $status == 2 ) {
                $label = __( 'Active', 'wpiptrac' );
            } elseif ( $status == 3 ) {
                $label = __( 'Closed', 'wpiptrac' );
            } elseif ( $status == 4 ) {
                $label = __( 'Rejected', 'wpiptrac' );
            }
            return $label;
        }
        
        /**
         * Get column actions
         *
         * @param object $item
         * @return void
         */
        public function column_actions( $item ) 
        {
            $linkEdit = admin_url() . 'admin.php?page=iptrac-admin-manage&action=edit&id='.$item->tick_id;
            $linkDel  = '#toDeleteTicket_'.$item->tick_id;
            $actions  = '<div class="ip_tickActions">
                            <a class="ip_tickEdit ipadm-btn ipadm-btn-primary ipadm-btn-small" href="' . $linkEdit . '">' . 
                                '<i class="fa fa-pencil"></i><span class="ipadm-separator"></span>' .
                                __( 'Edit', 'wpiptrac' ) . '
                            </a>
                            <a class="ip_tickDelete ipadm-btn ipadm-btn-danger ipadm-btn-small" href="' . $linkDel . '">' .
                                '<i class="fa fa-trash-o"></i><span class="ipadm-separator"></span>' . 
                                __( 'Delete', 'wpiptrac' ) . '
                            </a>
                        </div>';
            
            return $actions;
        }

        /**
         * Get column default
         *
         */
        public function column_default() 
        {
            return '';
        }
    }

}
?>