<?php
/*
Plugin Name: WP EZ Ticketing
Plugin URI:
Description: Ticketing support plugin
Version: 1.0
Author: Free PLR Products
Author URI: http://resell-rights-weekly.com
*/

/*
    LICENSE: This source file to be part of a system developed by InstaPRoduct.
    All copyrights use this file and the code in it owned by InstaPRoduct.
    It is strictly forbidden to use, copy, modify or distribute this file and
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPTRAC_TITLE', 'WP EZ Ticketing' );
define( 'IPTRAC_FILE', __FILE__ );
define( 'IPTRAC_PATH', plugin_dir_path( __FILE__ ) );

require_once( plugin_dir_path( __FILE__ ) . "includes/setting.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/db.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/model.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/admin.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/admin-ticket.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/form.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/mail.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/sender.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/history.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/ajax.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/shortcode.php" );

/**
 * Class for generate notification
 */
if ( ! class_exists( 'IPTrac' )) {

    class IPTrac
    {
        /**
         * Setup Plugin
         */
        public function setup()
        {
            $hook = strtolower( IPTRAC_TITLE );
            $hook = preg_replace( '@[^a-zA-Z0-9\-]@', '-', $hook );

            //Install Plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'installDb' ) );

            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'updateDb' ) );

            //Plugin init
            add_action( 'admin_init', array( __CLASS__, 'init' ) );

            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'addAdminMenu' ) );

            //Register post type
            add_action( 'init', array( __CLASS__, 'regPostType' ) );
            //Add support message for post type
            add_filter( 'post_updated_messages', array( __CLASS__, 'getPostTypeMessages' ) );

            //Post type shortcode
            add_shortcode( 'ip_troubleshooter', array( 'IPTrac_Shortcode', 'troubleshooter' ) );
            add_shortcode( 'ip_knowledge', array( 'IPTrac_Shortcode', 'knowledge' ) );


            //Add style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'printAdminStyle' ), 1000 );

            add_action( 'admin_print_scripts-toplevel_page_iptrac-user-manage', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-toplevel_page_iptrac-admin-manage', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptrac-user-send', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptrac-admin-product', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptrac-admin-type', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptrac-admin-focus', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptrac-admin-setting', array( __CLASS__, 'printAdminScript' ), 1000 );

            //Front style & script
            add_action('wp_head', array( __CLASS__, 'printStyle' ) );

        }

        /**
         * Init
         *
         * @return void
         */
        public function init()
        {
            global $iptrac_sender, $wp_roles;

            /**
             * Register Roles
             */
            // Add capability for subscriber
            $role = get_role( 'subscriber' );
            $role->add_cap( 'iptrac_subscriber_manage' );

            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'iptrac_admin_manage' );
            $role->add_cap( 'iptrac_knowledge_manage' );
            $role->add_cap( 'iptrac_trouble_manage' );

            $wp_roles->reinit();

            /**
             * AJax Handler
             */
            $ajax = new IPTrac_Ajax();
            $ajax->exec();

            /**
             * Form handler
             **/
            if ( isset( $_GET['page'] ) && $_GET['page'] == 'iptrac-user-send' )
            {
                $handler = new IPTrac_Sender();
                $handler->run();
                $iptrac_sender = $handler;
            }
        }

        /**
         * Register post type
         *
         * @return void
         */
        public function regPostType()
        {
            /**
             * Register knowledge post type
             */
            $labels = array(
                'name'               => _x( 'Knowledge Bases', 'post type general name' ),
                'singular_name'      => _x( 'Knowledge Base', 'post type singular name' ),
                'add_new'            => _x( 'Add New', 'book' ),
                'add_new_item'       => __( 'Add New Knowledge' ),
                'edit_item'          => __( 'Edit Knowledge' ),
                'new_item'           => __( 'New Knowledge' ),
                'all_items'          => __( 'All Knowledges' ),
                'view_item'          => __( 'View Knowledge' ),
                'search_items'       => __( 'Search Knowledges' ),
                'not_found'          => __( 'No Knowledges found' ),
                'not_found_in_trash' => __( 'No Knowledges found in the Trash' ),
                'parent_item_colon'  => '',
                'menu_name'          => 'Knowledge Bases'
            );
            $args = array(
                'labels'        => $labels,
                'description'   => 'Holds our knowledges and knowledge specific data',
                'public'        => true,
                'menu_position' => 78,
                'menu_icon'     => 'dashicons-lightbulb',
                'supports'      => array( 'title', 'editor', 'excerpt', 'comments' ),
                'has_archive'   => false,
            );
            register_post_type( 'knowledge', $args );


            /** Register category **/
            $labels = array(
                'name'              => _x( 'Knowledge Categories', 'taxonomy general name' ),
                'singular_name'     => _x( 'Knowledge Category', 'taxonomy singular name' ),
                'search_items'      => __( 'Search Knowledge Categories' ),
                'all_items'         => __( 'All Categories' ),
                'parent_item'       => __( 'Parent Category' ),
                'parent_item_colon' => __( 'Parent Category:' ),
                'edit_item'         => __( 'Edit Category' ),
                'update_item'       => __( 'Update Category' ),
                'add_new_item'      => __( 'Add New Category' ),
                'new_item_name'     => __( 'New Category' ),
                'menu_name'         => __( 'Categories' ),
            );
            $args = array(
                'labels'        => $labels,
                'hierarchical'  => true,
            );
            register_taxonomy( 'knowledge_category', 'knowledge', $args );


            /**
             * Register troubleshooter post type
             */
            $labels = array(
                'name'               => _x( 'Troubleshooters', 'post type general name' ),
                'singular_name'      => _x( 'Troubleshooter', 'post type singular name' ),
                'add_new'            => _x( 'Add New', 'book' ),
                'add_new_item'       => __( 'Add New Trouble' ),
                'edit_item'          => __( 'Edit Trouble' ),
                'new_item'           => __( 'New Trouble' ),
                'all_items'          => __( 'All Troubles' ),
                'view_item'          => __( 'View Trouble' ),
                'search_items'       => __( 'Search Troubles' ),
                'not_found'          => __( 'No Troubles found' ),
                'not_found_in_trash' => __( 'No Troubles found in the Trash' ),
                'parent_item_colon'  => '',
                'menu_name'          => 'Troubleshooters'
            );
            $args = array(
                'labels'        => $labels,
                'description'   => 'Holds our troubleshooters and troubleshooter specific data',
                'public'        => true,
                'menu_position' => 79,
                'menu_icon'     => 'dashicons-admin-tools',
                'supports'      => array( 'title', 'editor', 'excerpt', 'comments' ),
                'has_archive'   => false,
            );
            register_post_type( 'troubleshooter', $args );
        }

        /**
         * Get post type messages
         *
         * @return void
         */
        public function getPostTypeMessages( $messages )
        {
            global $post, $post_ID;

            //Message for knowledge post type
            $messages['knowledge'] = array(
                0 => '',
                1 => sprintf( __('Knowledge Base updated. <a href="%s">View knowledge base</a>'), esc_url( get_permalink($post_ID) ) ),
                2 => __('Custom field updated.'),
                3 => __('Custom field deleted.'),
                4 => __('Knowledge Base updated.'),
                5 => isset($_GET['revision']) ? sprintf( __('Knowledge Base restored to revision from %s'), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
                6 => sprintf( __('Knowledge Base published. <a href="%s">View knowledge base</a>'), esc_url( get_permalink($post_ID) ) ),
                7 => __('Knowledge Base saved.'),
                8 => sprintf( __('Knowledge Base submitted. <a target="_blank" href="%s">Preview knowledge base</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
                9 => sprintf( __('Knowledge Base scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview knowledge base</a>'), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
                10 => sprintf( __('Knowledge Base draft updated. <a target="_blank" href="%s">Preview knowledge base</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
            );

            //Message for trouble shooter post type
            $messages['troubleshooter'] = array(
                0 => '',
                1 => sprintf( __('Troubleshooter updated. <a href="%s">View troubleshooter</a>'), esc_url( get_permalink($post_ID) ) ),
                2 => __('Custom field updated.'),
                3 => __('Custom field deleted.'),
                4 => __('Troubleshooter updated.'),
                5 => isset($_GET['revision']) ? sprintf( __('Troubleshooter restored to revision from %s'), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
                6 => sprintf( __('Troubleshooter published. <a href="%s">View troubleshooter</a>'), esc_url( get_permalink($post_ID) ) ),
                7 => __('Troubleshooter saved.'),
                8 => sprintf( __('Troubleshooter submitted. <a target="_blank" href="%s">Preview troubleshooter</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
                9 => sprintf( __('Troubleshooter scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview troubleshooter</a>'), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
                10 => sprintf( __('Troubleshooter draft updated. <a target="_blank" href="%s">Preview troubleshooter</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
            );

            return $messages;
        }

        /**
         * Install Db
         *
         * @return void
         */
        public function installDb()
        {
            $db = new IPTrac_Db();
            $db->install();
        }

        /**
         * Update Db
         *
         * @return void
         */
        public function updateDb()
        {
            $db = new IPTrac_Db();
            $db->update();
        }

        /**
         * Add administrator menu
         *
         * @return void
         */
        public function addAdminMenu()
        {
            //Menu for user
            add_menu_page(
                IPTRAC_TITLE,
                IPTRAC_TITLE,
                'iptrac_subscriber_manage',
                'iptrac-user-manage',
                array( __CLASS__, 'adminPage' ),
                'dashicons-editor-help'
            );
            add_submenu_page(
                'iptrac-user-manage',
                __( 'All Tickets', 'wpiptrac' ),
                __( 'All Tickets', 'wpiptrac' ),
                'iptrac_subscriber_manage',
                'iptrac-user-manage',
                array( __CLASS__, 'adminPage' )
            );
            add_submenu_page(
                'iptrac-user-manage',
                __( 'Send Ticket', 'wpiptrac' ),
                __( 'Send Ticket', 'wpiptrac' ),
                'iptrac_subscriber_manage',
                'iptrac-user-send',
                array( __CLASS__, 'adminPage' )
            );

            //Menu for admin
            add_menu_page(
                IPTRAC_TITLE,
                IPTRAC_TITLE,
                'iptrac_admin_manage',
                'iptrac-admin-manage',
                array( __CLASS__, 'adminPage' ),
                'dashicons-editor-help',
                77
            );
            add_submenu_page(
                'iptrac-admin-manage',
                __( 'All Tickets', 'wpiptrac' ),
                __( 'All Tickets', 'wpiptrac' ),
                'iptrac_admin_manage',
                'iptrac-admin-manage',
                array( __CLASS__, 'adminPage' )
            );
            add_submenu_page(
                'iptrac-admin-manage',
                __( 'Product', 'wpiptrac' ),
                __( 'Product', 'wpiptrac' ),
                'iptrac_admin_manage',
                'iptrac-admin-product',
                array( __CLASS__, 'adminPage' )
            );
            add_submenu_page(
                'iptrac-admin-manage',
                __( 'Type Option', 'wpiptrac' ),
                __( 'Type Option', 'wpiptrac' ),
                'iptrac_admin_manage',
                'iptrac-admin-type',
                array( __CLASS__, 'adminPage' )
            );
            add_submenu_page(
                'iptrac-admin-manage',
                __( 'Focus Option', 'wpiptrac' ),
                __( 'Focus Option', 'wpiptrac' ),
                'iptrac_admin_manage',
                'iptrac-admin-focus',
                array( __CLASS__, 'adminPage' )
            );
            add_submenu_page(
                'iptrac-admin-manage',
                __( 'Settings', 'wpiptrac' ),
                __( 'Settings', 'wpiptrac' ),
                'iptrac_admin_manage',
                'iptrac-admin-setting',
                array( __CLASS__, 'adminPage' )
            );
        }

        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminPage()
        {
            $display = new IPTrac_Admin();
            $display->render();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public function printAdminStyle()
        {
            wp_deregister_style('font-awesome-style');
            wp_register_style('font-awesome-style', '//netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css', false, null);
            wp_enqueue_style('font-awesome-style');

            wp_deregister_style('insta-admin-style');
            wp_register_style('insta-admin-style', plugin_dir_url( __FILE__ ) . 'css/ipadmin.css', false, null);
            wp_enqueue_style('insta-admin-style');

            wp_deregister_style('wpiptrac-admin-style');
            wp_register_style('wpiptrac-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('wpiptrac-admin-style');

        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public function printAdminScript($hook)
        {
            wp_deregister_script('insta-admin-script');
            wp_enqueue_script(
                'insta-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/ipadmin.js',
                array( 'jquery' ),
                1,
                true
            );

            wp_deregister_script('wpiptrac-admin-script');
            wp_enqueue_script(
                'wpiptrac-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print style
         *
         * @return void
         */
        public function printStyle()
        {
        ?>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/style.css" rel="stylesheet">
        <?php
        }
    }

}
//Run plugin
IPTrac::setup();
?>